'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_vertex_program'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_vertex_program',error_checker=_errors._error_checker)
GL_ATTRIB_ARRAY_POINTER_NV=_C('GL_ATTRIB_ARRAY_POINTER_NV',0x8645)
GL_ATTRIB_ARRAY_SIZE_NV=_C('GL_ATTRIB_ARRAY_SIZE_NV',0x8623)
GL_ATTRIB_ARRAY_STRIDE_NV=_C('GL_ATTRIB_ARRAY_STRIDE_NV',0x8624)
GL_ATTRIB_ARRAY_TYPE_NV=_C('GL_ATTRIB_ARRAY_TYPE_NV',0x8625)
GL_CURRENT_ATTRIB_NV=_C('GL_CURRENT_ATTRIB_NV',0x8626)
GL_CURRENT_MATRIX_NV=_C('GL_CURRENT_MATRIX_NV',0x8641)
GL_CURRENT_MATRIX_STACK_DEPTH_NV=_C('GL_CURRENT_MATRIX_STACK_DEPTH_NV',0x8640)
GL_IDENTITY_NV=_C('GL_IDENTITY_NV',0x862A)
GL_INVERSE_NV=_C('GL_INVERSE_NV',0x862B)
GL_INVERSE_TRANSPOSE_NV=_C('GL_INVERSE_TRANSPOSE_NV',0x862D)
GL_MAP1_VERTEX_ATTRIB0_4_NV=_C('GL_MAP1_VERTEX_ATTRIB0_4_NV',0x8660)
GL_MAP1_VERTEX_ATTRIB10_4_NV=_C('GL_MAP1_VERTEX_ATTRIB10_4_NV',0x866A)
GL_MAP1_VERTEX_ATTRIB11_4_NV=_C('GL_MAP1_VERTEX_ATTRIB11_4_NV',0x866B)
GL_MAP1_VERTEX_ATTRIB12_4_NV=_C('GL_MAP1_VERTEX_ATTRIB12_4_NV',0x866C)
GL_MAP1_VERTEX_ATTRIB13_4_NV=_C('GL_MAP1_VERTEX_ATTRIB13_4_NV',0x866D)
GL_MAP1_VERTEX_ATTRIB14_4_NV=_C('GL_MAP1_VERTEX_ATTRIB14_4_NV',0x866E)
GL_MAP1_VERTEX_ATTRIB15_4_NV=_C('GL_MAP1_VERTEX_ATTRIB15_4_NV',0x866F)
GL_MAP1_VERTEX_ATTRIB1_4_NV=_C('GL_MAP1_VERTEX_ATTRIB1_4_NV',0x8661)
GL_MAP1_VERTEX_ATTRIB2_4_NV=_C('GL_MAP1_VERTEX_ATTRIB2_4_NV',0x8662)
GL_MAP1_VERTEX_ATTRIB3_4_NV=_C('GL_MAP1_VERTEX_ATTRIB3_4_NV',0x8663)
GL_MAP1_VERTEX_ATTRIB4_4_NV=_C('GL_MAP1_VERTEX_ATTRIB4_4_NV',0x8664)
GL_MAP1_VERTEX_ATTRIB5_4_NV=_C('GL_MAP1_VERTEX_ATTRIB5_4_NV',0x8665)
GL_MAP1_VERTEX_ATTRIB6_4_NV=_C('GL_MAP1_VERTEX_ATTRIB6_4_NV',0x8666)
GL_MAP1_VERTEX_ATTRIB7_4_NV=_C('GL_MAP1_VERTEX_ATTRIB7_4_NV',0x8667)
GL_MAP1_VERTEX_ATTRIB8_4_NV=_C('GL_MAP1_VERTEX_ATTRIB8_4_NV',0x8668)
GL_MAP1_VERTEX_ATTRIB9_4_NV=_C('GL_MAP1_VERTEX_ATTRIB9_4_NV',0x8669)
GL_MAP2_VERTEX_ATTRIB0_4_NV=_C('GL_MAP2_VERTEX_ATTRIB0_4_NV',0x8670)
GL_MAP2_VERTEX_ATTRIB10_4_NV=_C('GL_MAP2_VERTEX_ATTRIB10_4_NV',0x867A)
GL_MAP2_VERTEX_ATTRIB11_4_NV=_C('GL_MAP2_VERTEX_ATTRIB11_4_NV',0x867B)
GL_MAP2_VERTEX_ATTRIB12_4_NV=_C('GL_MAP2_VERTEX_ATTRIB12_4_NV',0x867C)
GL_MAP2_VERTEX_ATTRIB13_4_NV=_C('GL_MAP2_VERTEX_ATTRIB13_4_NV',0x867D)
GL_MAP2_VERTEX_ATTRIB14_4_NV=_C('GL_MAP2_VERTEX_ATTRIB14_4_NV',0x867E)
GL_MAP2_VERTEX_ATTRIB15_4_NV=_C('GL_MAP2_VERTEX_ATTRIB15_4_NV',0x867F)
GL_MAP2_VERTEX_ATTRIB1_4_NV=_C('GL_MAP2_VERTEX_ATTRIB1_4_NV',0x8671)
GL_MAP2_VERTEX_ATTRIB2_4_NV=_C('GL_MAP2_VERTEX_ATTRIB2_4_NV',0x8672)
GL_MAP2_VERTEX_ATTRIB3_4_NV=_C('GL_MAP2_VERTEX_ATTRIB3_4_NV',0x8673)
GL_MAP2_VERTEX_ATTRIB4_4_NV=_C('GL_MAP2_VERTEX_ATTRIB4_4_NV',0x8674)
GL_MAP2_VERTEX_ATTRIB5_4_NV=_C('GL_MAP2_VERTEX_ATTRIB5_4_NV',0x8675)
GL_MAP2_VERTEX_ATTRIB6_4_NV=_C('GL_MAP2_VERTEX_ATTRIB6_4_NV',0x8676)
GL_MAP2_VERTEX_ATTRIB7_4_NV=_C('GL_MAP2_VERTEX_ATTRIB7_4_NV',0x8677)
GL_MAP2_VERTEX_ATTRIB8_4_NV=_C('GL_MAP2_VERTEX_ATTRIB8_4_NV',0x8678)
GL_MAP2_VERTEX_ATTRIB9_4_NV=_C('GL_MAP2_VERTEX_ATTRIB9_4_NV',0x8679)
GL_MATRIX0_NV=_C('GL_MATRIX0_NV',0x8630)
GL_MATRIX1_NV=_C('GL_MATRIX1_NV',0x8631)
GL_MATRIX2_NV=_C('GL_MATRIX2_NV',0x8632)
GL_MATRIX3_NV=_C('GL_MATRIX3_NV',0x8633)
GL_MATRIX4_NV=_C('GL_MATRIX4_NV',0x8634)
GL_MATRIX5_NV=_C('GL_MATRIX5_NV',0x8635)
GL_MATRIX6_NV=_C('GL_MATRIX6_NV',0x8636)
GL_MATRIX7_NV=_C('GL_MATRIX7_NV',0x8637)
GL_MAX_TRACK_MATRICES_NV=_C('GL_MAX_TRACK_MATRICES_NV',0x862F)
GL_MAX_TRACK_MATRIX_STACK_DEPTH_NV=_C('GL_MAX_TRACK_MATRIX_STACK_DEPTH_NV',0x862E)
GL_MODELVIEW_PROJECTION_NV=_C('GL_MODELVIEW_PROJECTION_NV',0x8629)
GL_PROGRAM_ERROR_POSITION_NV=_C('GL_PROGRAM_ERROR_POSITION_NV',0x864B)
GL_PROGRAM_LENGTH_NV=_C('GL_PROGRAM_LENGTH_NV',0x8627)
GL_PROGRAM_PARAMETER_NV=_C('GL_PROGRAM_PARAMETER_NV',0x8644)
GL_PROGRAM_RESIDENT_NV=_C('GL_PROGRAM_RESIDENT_NV',0x8647)
GL_PROGRAM_STRING_NV=_C('GL_PROGRAM_STRING_NV',0x8628)
GL_PROGRAM_TARGET_NV=_C('GL_PROGRAM_TARGET_NV',0x8646)
GL_TRACK_MATRIX_NV=_C('GL_TRACK_MATRIX_NV',0x8648)
GL_TRACK_MATRIX_TRANSFORM_NV=_C('GL_TRACK_MATRIX_TRANSFORM_NV',0x8649)
GL_TRANSPOSE_NV=_C('GL_TRANSPOSE_NV',0x862C)
GL_VERTEX_ATTRIB_ARRAY0_NV=_C('GL_VERTEX_ATTRIB_ARRAY0_NV',0x8650)
GL_VERTEX_ATTRIB_ARRAY10_NV=_C('GL_VERTEX_ATTRIB_ARRAY10_NV',0x865A)
GL_VERTEX_ATTRIB_ARRAY11_NV=_C('GL_VERTEX_ATTRIB_ARRAY11_NV',0x865B)
GL_VERTEX_ATTRIB_ARRAY12_NV=_C('GL_VERTEX_ATTRIB_ARRAY12_NV',0x865C)
GL_VERTEX_ATTRIB_ARRAY13_NV=_C('GL_VERTEX_ATTRIB_ARRAY13_NV',0x865D)
GL_VERTEX_ATTRIB_ARRAY14_NV=_C('GL_VERTEX_ATTRIB_ARRAY14_NV',0x865E)
GL_VERTEX_ATTRIB_ARRAY15_NV=_C('GL_VERTEX_ATTRIB_ARRAY15_NV',0x865F)
GL_VERTEX_ATTRIB_ARRAY1_NV=_C('GL_VERTEX_ATTRIB_ARRAY1_NV',0x8651)
GL_VERTEX_ATTRIB_ARRAY2_NV=_C('GL_VERTEX_ATTRIB_ARRAY2_NV',0x8652)
GL_VERTEX_ATTRIB_ARRAY3_NV=_C('GL_VERTEX_ATTRIB_ARRAY3_NV',0x8653)
GL_VERTEX_ATTRIB_ARRAY4_NV=_C('GL_VERTEX_ATTRIB_ARRAY4_NV',0x8654)
GL_VERTEX_ATTRIB_ARRAY5_NV=_C('GL_VERTEX_ATTRIB_ARRAY5_NV',0x8655)
GL_VERTEX_ATTRIB_ARRAY6_NV=_C('GL_VERTEX_ATTRIB_ARRAY6_NV',0x8656)
GL_VERTEX_ATTRIB_ARRAY7_NV=_C('GL_VERTEX_ATTRIB_ARRAY7_NV',0x8657)
GL_VERTEX_ATTRIB_ARRAY8_NV=_C('GL_VERTEX_ATTRIB_ARRAY8_NV',0x8658)
GL_VERTEX_ATTRIB_ARRAY9_NV=_C('GL_VERTEX_ATTRIB_ARRAY9_NV',0x8659)
GL_VERTEX_PROGRAM_BINDING_NV=_C('GL_VERTEX_PROGRAM_BINDING_NV',0x864A)
GL_VERTEX_PROGRAM_NV=_C('GL_VERTEX_PROGRAM_NV',0x8620)
GL_VERTEX_PROGRAM_POINT_SIZE_NV=_C('GL_VERTEX_PROGRAM_POINT_SIZE_NV',0x8642)
GL_VERTEX_PROGRAM_TWO_SIDE_NV=_C('GL_VERTEX_PROGRAM_TWO_SIDE_NV',0x8643)
GL_VERTEX_STATE_PROGRAM_NV=_C('GL_VERTEX_STATE_PROGRAM_NV',0x8621)
@_f
@_p.types(_cs.GLboolean,_cs.GLsizei,arrays.GLuintArray,arrays.GLbooleanArray)
def glAreProgramsResidentNV(n,programs,residences):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glBindProgramNV(target,id):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteProgramsNV(n,programs):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLfloatArray)
def glExecuteProgramNV(target,id,params):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenProgramsNV(n,programs):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLenum,arrays.GLdoubleArray)
def glGetProgramParameterdvNV(target,index,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLenum,arrays.GLfloatArray)
def glGetProgramParameterfvNV(target,index,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLubyteArray)
def glGetProgramStringNV(id,pname,program):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetProgramivNV(id,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetTrackMatrixivNV(target,address,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLvoidpArray)
def glGetVertexAttribPointervNV(index,pname,pointer):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLdoubleArray)
def glGetVertexAttribdvNV(index,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLfloatArray)
def glGetVertexAttribfvNV(index,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetVertexAttribivNV(index,pname,params):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsProgramNV(id):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLsizei,arrays.GLubyteArray)
def glLoadProgramNV(target,id,len,program):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glProgramParameter4dNV(target,index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLdoubleArray)
def glProgramParameter4dvNV(target,index,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glProgramParameter4fNV(target,index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLfloatArray)
def glProgramParameter4fvNV(target,index,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLsizei,arrays.GLdoubleArray)
def glProgramParameters4dvNV(target,index,count,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLsizei,arrays.GLfloatArray)
def glProgramParameters4fvNV(target,index,count,v):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glRequestResidentProgramsNV(n,programs):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLenum,_cs.GLenum)
def glTrackMatrixNV(target,address,matrix,transform):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLdouble)
def glVertexAttrib1dNV(index,x):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLdoubleArray)
def glVertexAttrib1dvNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLfloat)
def glVertexAttrib1fNV(index,x):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLfloatArray)
def glVertexAttrib1fvNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLshort)
def glVertexAttrib1sNV(index,x):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLshortArray)
def glVertexAttrib1svNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLdouble,_cs.GLdouble)
def glVertexAttrib2dNV(index,x,y):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLdoubleArray)
def glVertexAttrib2dvNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLfloat,_cs.GLfloat)
def glVertexAttrib2fNV(index,x,y):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLfloatArray)
def glVertexAttrib2fvNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLshort,_cs.GLshort)
def glVertexAttrib2sNV(index,x,y):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLshortArray)
def glVertexAttrib2svNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glVertexAttrib3dNV(index,x,y,z):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLdoubleArray)
def glVertexAttrib3dvNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glVertexAttrib3fNV(index,x,y,z):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLfloatArray)
def glVertexAttrib3fvNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glVertexAttrib3sNV(index,x,y,z):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLshortArray)
def glVertexAttrib3svNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glVertexAttrib4dNV(index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLdoubleArray)
def glVertexAttrib4dvNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glVertexAttrib4fNV(index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLfloatArray)
def glVertexAttrib4fvNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLshort,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glVertexAttrib4sNV(index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLshortArray)
def glVertexAttrib4svNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLubyte,_cs.GLubyte,_cs.GLubyte,_cs.GLubyte)
def glVertexAttrib4ubNV(index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLubyteArray)
def glVertexAttrib4ubvNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glVertexAttribPointerNV(index,fsize,type,stride,pointer):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLdoubleArray)
def glVertexAttribs1dvNV(index,count,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLfloatArray)
def glVertexAttribs1fvNV(index,count,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLshortArray)
def glVertexAttribs1svNV(index,count,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLdoubleArray)
def glVertexAttribs2dvNV(index,count,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLfloatArray)
def glVertexAttribs2fvNV(index,count,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLshortArray)
def glVertexAttribs2svNV(index,count,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLdoubleArray)
def glVertexAttribs3dvNV(index,count,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLfloatArray)
def glVertexAttribs3fvNV(index,count,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLshortArray)
def glVertexAttribs3svNV(index,count,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLdoubleArray)
def glVertexAttribs4dvNV(index,count,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLfloatArray)
def glVertexAttribs4fvNV(index,count,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLshortArray)
def glVertexAttribs4svNV(index,count,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLubyteArray)
def glVertexAttribs4ubvNV(index,count,v):pass



'''OpenGL extension IMG.read_format

This module customises the behaviour of the 
OpenGL.raw.GLES1.IMG.read_format to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension is intended to supplement the GL_OES_read_format
	extension by adding support for more format/type combinations to be used
	when calling ReadPixels.  ReadPixels currently accepts one fixed
	format/type combination (format RGBA and type UNSIGNED_BYTE) for
	portability, and an implementation specific format/type combination
	queried using the tokens IMPLEMENTATION_COLOR_READ_FORMAT_OES and
	IMPLEMENTATION_COLOR_READ_TYPE_OES (GL_OES_read_format extension).  This
	extension adds the following format/type combinations to those currently
	allowed to be returned by GetIntegerV:
	
	format                      type
	------                      ----
	BGRA_IMG                    UNSIGNED_BYTE
	BGRA_IMG                    UNSIGNED_SHORT_4_4_4_4_REV_IMG
	
	E.g. Calling GetIntegerv with a <pname> parameter of
	IMPLEMENTATION_COLOR_READ_FORMAT_OES can now return BGRA, with the
	corresponding call to GetIntegerv using a <pname> parameter of
	IMPLEMENTATION_COLOR_READ_TYPE_OES returning UNSIGNED_BYTE;

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/IMG/read_format.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES1 import _types, _glgets
from OpenGL.raw.GLES1.IMG.read_format import *
from OpenGL.raw.GLES1.IMG.read_format import _EXTENSION_NAME

def glInitReadFormatIMG():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.sRGB

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.sRGB to provide a more 
Python-friendly API

Overview (from the spec)
	
	The sRGB color space is based on typical (non-linear) response of the human
	eye.  It has been standardized by the International Electrotechnical 
	Commission (IEC) as IEC 61966-2-1.  The transfer function of sRGB roughly
	corresponds to a power function with a gamma of 2.2.
	
	FRAMEBUFFERS
	
	OpenGL assumes framebuffer color components are stored in a linear color
	space.  In particular, framebuffer blending is a linear operation.
	
	This extension adds a framebuffer capability for sRGB framebuffer update
	and blending.  When blending is disabled but the new sRGB updated mode is
	enabled (assume the framebuffer supports the capability), high-precision 
	linear color component values for red, green, and blue generated by
	fragment coloring are encoded for sRGB prior to being written into the
	framebuffer.  When blending is enabled along with the new sRGB update mode,
	red, green, and blue framebuffer color components are treated as sRGB
	values that are converted to linear color values, blended with the high-
	precision color values generated by fragment coloring, and then the blend
	result is encoded for sRGB just prior to being written into the 
	framebuffer.
	
	TEXTURES
	
	Conventional texture formats assume a linear color space.  So for a 
	conventional internal texture format such as GL_RGB8, the 256 discrete
	values for each 8-bit color component map linearly and uniformly to the
	[0,1] range.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/sRGB.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.sRGB import *
from OpenGL.raw.GLES2.EXT.sRGB import _EXTENSION_NAME

def glInitSrgbEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ATI.map_object_buffer

This module customises the behaviour of the 
OpenGL.raw.GL.ATI.map_object_buffer to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a mechanism for an application to obtain
	the virtual address of an object buffer. This allows the
	application to directly update the contents of an object buffer
	and avoid any intermediate copies.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ATI/map_object_buffer.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ATI.map_object_buffer import *
from OpenGL.raw.GL.ATI.map_object_buffer import _EXTENSION_NAME

def glInitMapObjectBufferATI():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.texture_shadow_lod

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.texture_shadow_lod to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds support for various shadow sampler types with texture
	functions having interactions with the LOD of texture lookups.  Modern
	shading languages support LOD queries for shadow sampler types, but until
	now the OpenGL Shading Language Specification has excluded multiple texture
	function overloads involving LOD calculations with various shadow samplers.
	Shading languages for other APIs do support the equivalent LOD-based
	texture sampling functions for these types which has made porting between
	those shading languages to GLSL cumbersome and has required the usage of
	sub-optimal workarounds.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/texture_shadow_lod.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.texture_shadow_lod import *
from OpenGL.raw.GLES2.EXT.texture_shadow_lod import _EXTENSION_NAME

def glInitTextureShadowLodEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_EXT_blend_minmax'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_EXT_blend_minmax',error_checker=_errors._error_checker)
GL_BLEND_EQUATION_EXT=_C('GL_BLEND_EQUATION_EXT',0x8009)
GL_FUNC_ADD_EXT=_C('GL_FUNC_ADD_EXT',0x8006)
GL_MAX_EXT=_C('GL_MAX_EXT',0x8008)
GL_MIN_EXT=_C('GL_MIN_EXT',0x8007)
@_f
@_p.types(None,_cs.GLenum)
def glBlendEquationEXT(mode):pass



from OpenGL.platform import PLATFORM as _p
from OpenGL.error import _ErrorChecker
if _p.GLES1 and _p.GLES1.glGetError and _ErrorChecker:
    _error_checker = _ErrorChecker( _p, _p.GLES1.glGetError )
else:
    _error_checker = None



'''OpenGL extension OES.read_format

This module customises the behaviour of the 
OpenGL.raw.GL.OES.read_format to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides the capability to query an OpenGL
	implementation for a preferred type and format combination
	for use with reading the color buffer with the ReadPixels
	command.  The purpose is to enable embedded implementations
	to support a greatly reduced set of type/format combinations
	and provide a mechanism for applications to determine which
	implementation-specific combination is supported.
	
	The preferred type and format combination returned may depend
	on the read surface bound to the current GL context.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/read_format.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.OES.read_format import *
from OpenGL.raw.GL.OES.read_format import _EXTENSION_NAME

def glInitReadFormatOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ARB.shader_bit_encoding

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.shader_bit_encoding to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension trivially adds built-in functions for getting/setting
	the bit encoding for floating-point values in the OpenGL Shading Language.
	
	These functions are pulled out of ARB_gpu_shader5, since support for such
	built-in functions exists in current hardware.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/shader_bit_encoding.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.shader_bit_encoding import *
from OpenGL.raw.GL.ARB.shader_bit_encoding import _EXTENSION_NAME

def glInitShaderBitEncodingARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension QCOM.YUV_texture_gather

This module customises the behaviour of the 
OpenGL.raw.GLES2.QCOM.YUV_texture_gather to provide a more 
Python-friendly API

Overview (from the spec)
	
	Extension EXT_gpu_shader5 introduced the texture gather built-in functions.
	Extension EXT_YUV_target adds the ability to sample from YUV textures, but
	does not include gather functions.   This extension allows gather function
	to be used in combination with the YUV textures exposed in EXT_YUV_target.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/QCOM/YUV_texture_gather.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.QCOM.YUV_texture_gather import *
from OpenGL.raw.GLES2.QCOM.YUV_texture_gather import _EXTENSION_NAME

def glInitYuvTextureGatherQCOM():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension IMG.texture_compression_pvrtc2

This module customises the behaviour of the 
OpenGL.raw.GLES2.IMG.texture_compression_pvrtc2 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides additional texture compression functionality
	specific to Imagination Technologies PowerVR Texture compression format
	(called PVRTC2) subject to all the requirements and limitations
	described by the OpenGL ES 2.0 specification.
	
	This extension supports 4 and 2 bit per pixel texture compression
	formats. Because the compression of PVRTC2 is CPU intensive,
	it is not appropriate to carry out compression on the target
	platform. Therefore this extension only supports the loading of
	compressed texture data.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/IMG/texture_compression_pvrtc2.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.IMG.texture_compression_pvrtc2 import *
from OpenGL.raw.GLES2.IMG.texture_compression_pvrtc2 import _EXTENSION_NAME

def glInitTextureCompressionPvrtc2IMG():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension SGIX.igloo_interface

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.igloo_interface to provide a more 
Python-friendly API

Overview (from the spec)
	
	This is an SGI internal (e.g. not documented or intended to be used
	directly by applications) extension used only to help support
	emulation of IrisGL through OpenGL.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/igloo_interface.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIX.igloo_interface import *
from OpenGL.raw.GL.SGIX.igloo_interface import _EXTENSION_NAME

def glInitIglooInterfaceSGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glIglooInterfaceSGIX.params size not checked against 'pname'
glIglooInterfaceSGIX=wrapper.wrapper(glIglooInterfaceSGIX).setInputArraySize(
    'params', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension EXT.texture_rg

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.texture_rg to provide a more 
Python-friendly API

Overview (from the spec)
	
	Historically one- and two-component textures have been specified in OpenGL
	ES using the luminance or luminance-alpha (L/LA) formats. With the advent
	of programmable shaders and render-to-texture capabilities these legacy
	formats carry some historical artifacts which are no longer useful.
	
	For example, when sampling from such textures, the luminance values are
	replicated across the color components. This is no longer necessary with
	programmable shaders.
	
	It is also desirable to be able to render to one- and two-component format
	textures using capabilities such as framebuffer objects (FBO), but
	rendering to L/LA formats is under-specified (specifically how to map
	R/G/B/A values to L/A texture channels).
	
	This extension adds new base internal formats for one-component RED and
	two-component RG (red green) textures as well as sized RED and RG internal
	formats for renderbuffers. The RED and RG texture formats can be used for
	both texturing and rendering into with framebuffer objects.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/texture_rg.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.texture_rg import *
from OpenGL.raw.GLES2.EXT.texture_rg import _EXTENSION_NAME

def glInitTextureRgEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION
from OpenGL import images as _images
_images.COMPONENT_COUNTS.update( {
GL_R8_EXT:1,
GL_RED_EXT:1,
GL_RG8_EXT:2,
GL_RG_EXT:2,
})



'''OpenGL extension ARB.sparse_texture_clamp

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.sparse_texture_clamp to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension builds on the ARB_sparse_texture2 extension, providing the
	following new functionality:
	
	  * New built-in GLSL texture lookup functions are provided that specify a
	    minimum level of detail to use for lookups where the level of detail
	    is computed automatically.  This allows shaders to avoid accessing
	    unpopulated portions of high-resolution levels of detail when it knows
	    that the memory accessed is unpopulated, either from a priori
	    knowledge or from feedback provided by the return value of previously
	    executed "sparse" texture lookup functions.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/sparse_texture_clamp.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.sparse_texture_clamp import *
from OpenGL.raw.GL.ARB.sparse_texture_clamp import _EXTENSION_NAME

def glInitSparseTextureClampARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension QCOM.texture_foveated_subsampled_layout

This module customises the behaviour of the 
OpenGL.raw.GLES2.QCOM.texture_foveated_subsampled_layout to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension builds on QCOM_texture_foveated by introducing a new foveation
	method bit that aims to reduce memory bandwidth by avoiding the upscaling that
	occurred as part of the original extension.
	
	With the original FOVEATION_SCALED_BIN_METHOD_BIT_QCOM foveation method,
	the render target in system memory is entirely populated. The lower
	resolution framebuffer data is upscaled to fill the entire render target.
	The subsampled layout method introduced in this extension leaves the
	framebuffer data at the calculated lower density and instead samples
	directly from the the lower resolution texels.
	
	The primary usecase this is targeting is traditional VR pipeline. The
	application eye buffers would be rendered as textures with a subsampled layout
	and then sampled by the warp process. Sampling from a texture with a
	subsampled layout requires a new sampler layout qualifier.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/QCOM/texture_foveated_subsampled_layout.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.QCOM.texture_foveated_subsampled_layout import *
from OpenGL.raw.GLES2.QCOM.texture_foveated_subsampled_layout import _EXTENSION_NAME

def glInitTextureFoveatedSubsampledLayoutQCOM():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension OES.single_precision

This module customises the behaviour of the 
OpenGL.raw.GLES1.OES.single_precision to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds commands with single-precision floating-point
	parameters corresponding to the commands that only variants that
	accept double-precision floating-point input.  This allows an
	application to avoid using double-precision floating-point
	data types.  New commands are added with an 'f' prefix.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/single_precision.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES1 import _types, _glgets
from OpenGL.raw.GLES1.OES.single_precision import *
from OpenGL.raw.GLES1.OES.single_precision import _EXTENSION_NAME

def glInitSinglePrecisionOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glClipPlanefOES=wrapper.wrapper(glClipPlanefOES).setInputArraySize(
    'equation', 4
)
glGetClipPlanefOES=wrapper.wrapper(glGetClipPlanefOES).setOutput(
    'equation',size=(4,),orPassIn=True
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_vertex_shader'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_vertex_shader',error_checker=_errors._error_checker)
GL_CURRENT_VERTEX_EXT=_C('GL_CURRENT_VERTEX_EXT',0x87E2)
GL_FULL_RANGE_EXT=_C('GL_FULL_RANGE_EXT',0x87E1)
GL_INVARIANT_DATATYPE_EXT=_C('GL_INVARIANT_DATATYPE_EXT',0x87EB)
GL_INVARIANT_EXT=_C('GL_INVARIANT_EXT',0x87C2)
GL_INVARIANT_VALUE_EXT=_C('GL_INVARIANT_VALUE_EXT',0x87EA)
GL_LOCAL_CONSTANT_DATATYPE_EXT=_C('GL_LOCAL_CONSTANT_DATATYPE_EXT',0x87ED)
GL_LOCAL_CONSTANT_EXT=_C('GL_LOCAL_CONSTANT_EXT',0x87C3)
GL_LOCAL_CONSTANT_VALUE_EXT=_C('GL_LOCAL_CONSTANT_VALUE_EXT',0x87EC)
GL_LOCAL_EXT=_C('GL_LOCAL_EXT',0x87C4)
GL_MATRIX_EXT=_C('GL_MATRIX_EXT',0x87C0)
GL_MAX_OPTIMIZED_VERTEX_SHADER_INSTRUCTIONS_EXT=_C('GL_MAX_OPTIMIZED_VERTEX_SHADER_INSTRUCTIONS_EXT',0x87CA)
GL_MAX_OPTIMIZED_VERTEX_SHADER_INVARIANTS_EXT=_C('GL_MAX_OPTIMIZED_VERTEX_SHADER_INVARIANTS_EXT',0x87CD)
GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCALS_EXT=_C('GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCALS_EXT',0x87CE)
GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCAL_CONSTANTS_EXT=_C('GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCAL_CONSTANTS_EXT',0x87CC)
GL_MAX_OPTIMIZED_VERTEX_SHADER_VARIANTS_EXT=_C('GL_MAX_OPTIMIZED_VERTEX_SHADER_VARIANTS_EXT',0x87CB)
GL_MAX_VERTEX_SHADER_INSTRUCTIONS_EXT=_C('GL_MAX_VERTEX_SHADER_INSTRUCTIONS_EXT',0x87C5)
GL_MAX_VERTEX_SHADER_INVARIANTS_EXT=_C('GL_MAX_VERTEX_SHADER_INVARIANTS_EXT',0x87C7)
GL_MAX_VERTEX_SHADER_LOCALS_EXT=_C('GL_MAX_VERTEX_SHADER_LOCALS_EXT',0x87C9)
GL_MAX_VERTEX_SHADER_LOCAL_CONSTANTS_EXT=_C('GL_MAX_VERTEX_SHADER_LOCAL_CONSTANTS_EXT',0x87C8)
GL_MAX_VERTEX_SHADER_VARIANTS_EXT=_C('GL_MAX_VERTEX_SHADER_VARIANTS_EXT',0x87C6)
GL_MVP_MATRIX_EXT=_C('GL_MVP_MATRIX_EXT',0x87E3)
GL_NEGATIVE_ONE_EXT=_C('GL_NEGATIVE_ONE_EXT',0x87DF)
GL_NEGATIVE_W_EXT=_C('GL_NEGATIVE_W_EXT',0x87DC)
GL_NEGATIVE_X_EXT=_C('GL_NEGATIVE_X_EXT',0x87D9)
GL_NEGATIVE_Y_EXT=_C('GL_NEGATIVE_Y_EXT',0x87DA)
GL_NEGATIVE_Z_EXT=_C('GL_NEGATIVE_Z_EXT',0x87DB)
GL_NORMALIZED_RANGE_EXT=_C('GL_NORMALIZED_RANGE_EXT',0x87E0)
GL_ONE_EXT=_C('GL_ONE_EXT',0x87DE)
GL_OP_ADD_EXT=_C('GL_OP_ADD_EXT',0x8787)
GL_OP_CLAMP_EXT=_C('GL_OP_CLAMP_EXT',0x878E)
GL_OP_CROSS_PRODUCT_EXT=_C('GL_OP_CROSS_PRODUCT_EXT',0x8797)
GL_OP_DOT3_EXT=_C('GL_OP_DOT3_EXT',0x8784)
GL_OP_DOT4_EXT=_C('GL_OP_DOT4_EXT',0x8785)
GL_OP_EXP_BASE_2_EXT=_C('GL_OP_EXP_BASE_2_EXT',0x8791)
GL_OP_FLOOR_EXT=_C('GL_OP_FLOOR_EXT',0x878F)
GL_OP_FRAC_EXT=_C('GL_OP_FRAC_EXT',0x8789)
GL_OP_INDEX_EXT=_C('GL_OP_INDEX_EXT',0x8782)
GL_OP_LOG_BASE_2_EXT=_C('GL_OP_LOG_BASE_2_EXT',0x8792)
GL_OP_MADD_EXT=_C('GL_OP_MADD_EXT',0x8788)
GL_OP_MAX_EXT=_C('GL_OP_MAX_EXT',0x878A)
GL_OP_MIN_EXT=_C('GL_OP_MIN_EXT',0x878B)
GL_OP_MOV_EXT=_C('GL_OP_MOV_EXT',0x8799)
GL_OP_MULTIPLY_MATRIX_EXT=_C('GL_OP_MULTIPLY_MATRIX_EXT',0x8798)
GL_OP_MUL_EXT=_C('GL_OP_MUL_EXT',0x8786)
GL_OP_NEGATE_EXT=_C('GL_OP_NEGATE_EXT',0x8783)
GL_OP_POWER_EXT=_C('GL_OP_POWER_EXT',0x8793)
GL_OP_RECIP_EXT=_C('GL_OP_RECIP_EXT',0x8794)
GL_OP_RECIP_SQRT_EXT=_C('GL_OP_RECIP_SQRT_EXT',0x8795)
GL_OP_ROUND_EXT=_C('GL_OP_ROUND_EXT',0x8790)
GL_OP_SET_GE_EXT=_C('GL_OP_SET_GE_EXT',0x878C)
GL_OP_SET_LT_EXT=_C('GL_OP_SET_LT_EXT',0x878D)
GL_OP_SUB_EXT=_C('GL_OP_SUB_EXT',0x8796)
GL_OUTPUT_COLOR0_EXT=_C('GL_OUTPUT_COLOR0_EXT',0x879B)
GL_OUTPUT_COLOR1_EXT=_C('GL_OUTPUT_COLOR1_EXT',0x879C)
GL_OUTPUT_FOG_EXT=_C('GL_OUTPUT_FOG_EXT',0x87BD)
GL_OUTPUT_TEXTURE_COORD0_EXT=_C('GL_OUTPUT_TEXTURE_COORD0_EXT',0x879D)
GL_OUTPUT_TEXTURE_COORD10_EXT=_C('GL_OUTPUT_TEXTURE_COORD10_EXT',0x87A7)
GL_OUTPUT_TEXTURE_COORD11_EXT=_C('GL_OUTPUT_TEXTURE_COORD11_EXT',0x87A8)
GL_OUTPUT_TEXTURE_COORD12_EXT=_C('GL_OUTPUT_TEXTURE_COORD12_EXT',0x87A9)
GL_OUTPUT_TEXTURE_COORD13_EXT=_C('GL_OUTPUT_TEXTURE_COORD13_EXT',0x87AA)
GL_OUTPUT_TEXTURE_COORD14_EXT=_C('GL_OUTPUT_TEXTURE_COORD14_EXT',0x87AB)
GL_OUTPUT_TEXTURE_COORD15_EXT=_C('GL_OUTPUT_TEXTURE_COORD15_EXT',0x87AC)
GL_OUTPUT_TEXTURE_COORD16_EXT=_C('GL_OUTPUT_TEXTURE_COORD16_EXT',0x87AD)
GL_OUTPUT_TEXTURE_COORD17_EXT=_C('GL_OUTPUT_TEXTURE_COORD17_EXT',0x87AE)
GL_OUTPUT_TEXTURE_COORD18_EXT=_C('GL_OUTPUT_TEXTURE_COORD18_EXT',0x87AF)
GL_OUTPUT_TEXTURE_COORD19_EXT=_C('GL_OUTPUT_TEXTURE_COORD19_EXT',0x87B0)
GL_OUTPUT_TEXTURE_COORD1_EXT=_C('GL_OUTPUT_TEXTURE_COORD1_EXT',0x879E)
GL_OUTPUT_TEXTURE_COORD20_EXT=_C('GL_OUTPUT_TEXTURE_COORD20_EXT',0x87B1)
GL_OUTPUT_TEXTURE_COORD21_EXT=_C('GL_OUTPUT_TEXTURE_COORD21_EXT',0x87B2)
GL_OUTPUT_TEXTURE_COORD22_EXT=_C('GL_OUTPUT_TEXTURE_COORD22_EXT',0x87B3)
GL_OUTPUT_TEXTURE_COORD23_EXT=_C('GL_OUTPUT_TEXTURE_COORD23_EXT',0x87B4)
GL_OUTPUT_TEXTURE_COORD24_EXT=_C('GL_OUTPUT_TEXTURE_COORD24_EXT',0x87B5)
GL_OUTPUT_TEXTURE_COORD25_EXT=_C('GL_OUTPUT_TEXTURE_COORD25_EXT',0x87B6)
GL_OUTPUT_TEXTURE_COORD26_EXT=_C('GL_OUTPUT_TEXTURE_COORD26_EXT',0x87B7)
GL_OUTPUT_TEXTURE_COORD27_EXT=_C('GL_OUTPUT_TEXTURE_COORD27_EXT',0x87B8)
GL_OUTPUT_TEXTURE_COORD28_EXT=_C('GL_OUTPUT_TEXTURE_COORD28_EXT',0x87B9)
GL_OUTPUT_TEXTURE_COORD29_EXT=_C('GL_OUTPUT_TEXTURE_COORD29_EXT',0x87BA)
GL_OUTPUT_TEXTURE_COORD2_EXT=_C('GL_OUTPUT_TEXTURE_COORD2_EXT',0x879F)
GL_OUTPUT_TEXTURE_COORD30_EXT=_C('GL_OUTPUT_TEXTURE_COORD30_EXT',0x87BB)
GL_OUTPUT_TEXTURE_COORD31_EXT=_C('GL_OUTPUT_TEXTURE_COORD31_EXT',0x87BC)
GL_OUTPUT_TEXTURE_COORD3_EXT=_C('GL_OUTPUT_TEXTURE_COORD3_EXT',0x87A0)
GL_OUTPUT_TEXTURE_COORD4_EXT=_C('GL_OUTPUT_TEXTURE_COORD4_EXT',0x87A1)
GL_OUTPUT_TEXTURE_COORD5_EXT=_C('GL_OUTPUT_TEXTURE_COORD5_EXT',0x87A2)
GL_OUTPUT_TEXTURE_COORD6_EXT=_C('GL_OUTPUT_TEXTURE_COORD6_EXT',0x87A3)
GL_OUTPUT_TEXTURE_COORD7_EXT=_C('GL_OUTPUT_TEXTURE_COORD7_EXT',0x87A4)
GL_OUTPUT_TEXTURE_COORD8_EXT=_C('GL_OUTPUT_TEXTURE_COORD8_EXT',0x87A5)
GL_OUTPUT_TEXTURE_COORD9_EXT=_C('GL_OUTPUT_TEXTURE_COORD9_EXT',0x87A6)
GL_OUTPUT_VERTEX_EXT=_C('GL_OUTPUT_VERTEX_EXT',0x879A)
GL_SCALAR_EXT=_C('GL_SCALAR_EXT',0x87BE)
GL_VARIANT_ARRAY_EXT=_C('GL_VARIANT_ARRAY_EXT',0x87E8)
GL_VARIANT_ARRAY_POINTER_EXT=_C('GL_VARIANT_ARRAY_POINTER_EXT',0x87E9)
GL_VARIANT_ARRAY_STRIDE_EXT=_C('GL_VARIANT_ARRAY_STRIDE_EXT',0x87E6)
GL_VARIANT_ARRAY_TYPE_EXT=_C('GL_VARIANT_ARRAY_TYPE_EXT',0x87E7)
GL_VARIANT_DATATYPE_EXT=_C('GL_VARIANT_DATATYPE_EXT',0x87E5)
GL_VARIANT_EXT=_C('GL_VARIANT_EXT',0x87C1)
GL_VARIANT_VALUE_EXT=_C('GL_VARIANT_VALUE_EXT',0x87E4)
GL_VECTOR_EXT=_C('GL_VECTOR_EXT',0x87BF)
GL_VERTEX_SHADER_BINDING_EXT=_C('GL_VERTEX_SHADER_BINDING_EXT',0x8781)
GL_VERTEX_SHADER_EXT=_C('GL_VERTEX_SHADER_EXT',0x8780)
GL_VERTEX_SHADER_INSTRUCTIONS_EXT=_C('GL_VERTEX_SHADER_INSTRUCTIONS_EXT',0x87CF)
GL_VERTEX_SHADER_INVARIANTS_EXT=_C('GL_VERTEX_SHADER_INVARIANTS_EXT',0x87D1)
GL_VERTEX_SHADER_LOCALS_EXT=_C('GL_VERTEX_SHADER_LOCALS_EXT',0x87D3)
GL_VERTEX_SHADER_LOCAL_CONSTANTS_EXT=_C('GL_VERTEX_SHADER_LOCAL_CONSTANTS_EXT',0x87D2)
GL_VERTEX_SHADER_OPTIMIZED_EXT=_C('GL_VERTEX_SHADER_OPTIMIZED_EXT',0x87D4)
GL_VERTEX_SHADER_VARIANTS_EXT=_C('GL_VERTEX_SHADER_VARIANTS_EXT',0x87D0)
GL_W_EXT=_C('GL_W_EXT',0x87D8)
GL_X_EXT=_C('GL_X_EXT',0x87D5)
GL_Y_EXT=_C('GL_Y_EXT',0x87D6)
GL_ZERO_EXT=_C('GL_ZERO_EXT',0x87DD)
GL_Z_EXT=_C('GL_Z_EXT',0x87D7)
@_f
@_p.types(None,)
def glBeginVertexShaderEXT():pass
@_f
@_p.types(_cs.GLuint,_cs.GLenum,_cs.GLenum)
def glBindLightParameterEXT(light,value):pass
@_f
@_p.types(_cs.GLuint,_cs.GLenum,_cs.GLenum)
def glBindMaterialParameterEXT(face,value):pass
@_f
@_p.types(_cs.GLuint,_cs.GLenum)
def glBindParameterEXT(value):pass
@_f
@_p.types(_cs.GLuint,_cs.GLenum,_cs.GLenum,_cs.GLenum)
def glBindTexGenParameterEXT(unit,coord,value):pass
@_f
@_p.types(_cs.GLuint,_cs.GLenum,_cs.GLenum)
def glBindTextureUnitParameterEXT(unit,value):pass
@_f
@_p.types(None,_cs.GLuint)
def glBindVertexShaderEXT(id):pass
@_f
@_p.types(None,_cs.GLuint)
def glDeleteVertexShaderEXT(id):pass
@_f
@_p.types(None,_cs.GLuint)
def glDisableVariantClientStateEXT(id):pass
@_f
@_p.types(None,_cs.GLuint)
def glEnableVariantClientStateEXT(id):pass
@_f
@_p.types(None,)
def glEndVertexShaderEXT():pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glExtractComponentEXT(res,src,num):pass
@_f
@_p.types(_cs.GLuint,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLuint)
def glGenSymbolsEXT(datatype,storagetype,range,components):pass
@_f
@_p.types(_cs.GLuint,_cs.GLuint)
def glGenVertexShadersEXT(range):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLbooleanArray)
def glGetInvariantBooleanvEXT(id,value,data):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLfloatArray)
def glGetInvariantFloatvEXT(id,value,data):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetInvariantIntegervEXT(id,value,data):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLbooleanArray)
def glGetLocalConstantBooleanvEXT(id,value,data):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLfloatArray)
def glGetLocalConstantFloatvEXT(id,value,data):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetLocalConstantIntegervEXT(id,value,data):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLbooleanArray)
def glGetVariantBooleanvEXT(id,value,data):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLfloatArray)
def glGetVariantFloatvEXT(id,value,data):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetVariantIntegervEXT(id,value,data):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLvoidpArray)
def glGetVariantPointervEXT(id,value,data):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glInsertComponentEXT(res,src,num):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint,_cs.GLenum)
def glIsVariantEnabledEXT(id,cap):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,ctypes.c_void_p)
def glSetInvariantEXT(id,type,addr):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,ctypes.c_void_p)
def glSetLocalConstantEXT(id,type,addr):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint)
def glShaderOp1EXT(op,res,arg1):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glShaderOp2EXT(op,res,arg1,arg2):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glShaderOp3EXT(op,res,arg1,arg2,arg3):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLenum)
def glSwizzleEXT(res,in_,outX,outY,outZ,outW):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLuint,ctypes.c_void_p)
def glVariantPointerEXT(id,type,stride,addr):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLbyteArray)
def glVariantbvEXT(id,addr):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLdoubleArray)
def glVariantdvEXT(id,addr):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLfloatArray)
def glVariantfvEXT(id,addr):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLintArray)
def glVariantivEXT(id,addr):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLshortArray)
def glVariantsvEXT(id,addr):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLubyteArray)
def glVariantubvEXT(id,addr):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLuintArray)
def glVariantuivEXT(id,addr):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLushortArray)
def glVariantusvEXT(id,addr):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLenum)
def glWriteMaskEXT(res,in_,outX,outY,outZ,outW):pass



'''OpenGL extension EXT.debug_label

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.debug_label to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension defines a mechanism for OpenGL and OpenGL ES applications to 
	label their objects (textures, buffers, shaders, etc.) with a descriptive 
	string. 
	
	When profiling or debugging such an application within a debugger or 
	profiler it is difficult to identify resources from their object names. 
	Even when the resource itself is viewed it can be problematic to 
	differentiate between similar resources. Attaching a label to an object         
	helps obviate this difficulty.
	
	The intended purpose of this is purely to improve the user experience 
	within OpenGL and OpenGL ES development tools.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/debug_label.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.debug_label import *
from OpenGL.raw.GLES2.EXT.debug_label import _EXTENSION_NAME

def glInitDebugLabelEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glGetObjectLabelEXT.label size not checked against bufSize
glGetObjectLabelEXT=wrapper.wrapper(glGetObjectLabelEXT).setInputArraySize(
    'label', None
).setInputArraySize(
    'length', 1
)
### END AUTOGENERATED SECTION


"""Image/texture implementation code

This module provides the Pan-OpenGL operations required to support OpenGL
image handling.  Most of this code is simply boilerplate code that sets 
OpenGL parameters such that normal Pythonic assumptions about data-ordering
are met to allow easier interaction with other projects (such as PIL or 
Numpy).

Generally speaking, there are 3 pieces of information which control how 
an image is processed in the system:

    format -- this is the pixel format, such as GL_RGB/GL_RED/GL_ABGR_EXT
    dims -- tuple of dimensions for the image, (width,height,depth) order 
    type -- the storage data-type for the image, normally GL_UNSIGNED_BYTE 
        when working in Python, but all of the standard OpenGL types for 
        images can be used if you happen to have your data in some exotic
        format.
    
    OpenGL.UNSIGNED_BYTE_IMAGES_AS_STRING -- if this global value is set,
        then read of unsigned byte images using glReadPixels and 
        glGetTexImage produces a string instead of the default array format.

Attributes of Note:

    COMPONENT_COUNTS -- used to lookup how many units of a 
        given storage type are required to store a unit in a given format
    
    TYPE_TO_ARRAYTYPE -- maps Image storage types to their array data-type
        constants, i.e. maps GL_UNSIGNED_SHORT_4_4_4_4 to GL_UNSIGNED_SHORT
        so that we can use the standard array types for manipulating 
        image arrays.
    
    RANK_PACKINGS -- commands required to set up default array-transfer 
        operations for an array of the specified rank.

New image formats and types will need to be registered here to be supported,
this means that extension modules which add image types/formats need to alter 
the tables described above!

    XXX Should be an API to handle that instead of direct modification.

"""
from OpenGL.raw.GL.VERSION import GL_1_1 as _simple
from OpenGL import arrays
from OpenGL import error
from OpenGL import _configflags
import ctypes

def SetupPixelRead( format, dims, type):
    """Setup transfer mode for a read into a numpy array return the array
    
    Calls setupDefaultTransferMode, sets rankPacking and then 
    returns a createTargetArray for the parameters.
    """
    setupDefaultTransferMode()
    # XXX this is wrong? dims may grow or it may not, depends on whether
    # the format can fit in the type or not, but rank is a property of the 
    # image itself?  Don't know, should test.
    rankPacking( len(dims)+1 )
    return createTargetArray( format, dims, type )

def setupDefaultTransferMode( ):
    """Set pixel transfer mode to assumed internal structure of arrays
    
    Basically OpenGL-ctypes (and PyOpenGL) assume that your image data is in 
    non-byte-swapped order, with big-endian ordering of bytes (though that 
    seldom matters in image data).  These assumptions are normally correct 
    when dealing with Python libraries which expose byte-arrays.
    """
    try:
        _simple.glPixelStorei(_simple.GL_PACK_SWAP_BYTES, 0)
        _simple.glPixelStorei(_simple.GL_PACK_LSB_FIRST, 0)
    except error.GLError:
        # GLES doesn't support pixel storage swapping...
        pass
        
def rankPacking( rank ):
    """Set the pixel-transfer modes for a given image "rank" (# of dims)
    
    Uses RANK_PACKINGS table to issue calls to glPixelStorei
    """
    for func,which,arg in RANK_PACKINGS[rank]:
        try:
            func(which,arg)
        except error.GLError:
            pass

def createTargetArray( format, dims, type ):
    """Create storage array for given parameters
    
    If storage type requires > 1 unit per format pixel, then dims will be
    extended by 1, so in the common case of RGB and GL_UNSIGNED_BYTE you 
    will wind up with an array of dims + (3,) dimensions.  See
    COMPONENT_COUNTS for table which controls which formats produce
    larger dimensions.  The secondary table TIGHT_PACK_FORMATS overrides 
    this case, so that image formats registered as TIGHT_PACK_FORMATS
    only ever return a dims-shaped value.  TIGHT_PACK_FORMATS will raise 
    ValueErrors if they are used with a format that does not have the same 
    number of components as they define.
    
    Note that the base storage type must provide a zeros method.  The zeros
    method relies on their being a registered default array-implementation for 
    the storage type.  The default installation of OpenGL-ctypes will use 
    Numpy arrays for returning the result.
    """
    # calculate the number of storage elements required to store 
    # a single pixel of format, that's the dimension of the resulting array
    componentCount = formatToComponentCount( format )
    if componentCount > 1:
        if type not in TIGHT_PACK_FORMATS:
            # requires multiple elements to store a single pixel (common)
            # e.g. byte array (typeBits = 8) with RGB (24) or RGBA (32)
            dims += (componentCount, )
        elif TIGHT_PACK_FORMATS[ type ] < componentCount:
            raise ValueError(
                """Image type: %s supports %s components, but format %s requires %s components"""%(
                    type,
                    TIGHT_PACK_FORMATS[ type ],
                    format,
                    componentCount,
                )
            )
    arrayType = arrays.GL_CONSTANT_TO_ARRAY_TYPE[ TYPE_TO_ARRAYTYPE.get(type,type) ]
    return arrayType.zeros( dims )

def formatToComponentCount( format ):
    """Given an OpenGL image format specification, get components/pixel"""
    size = COMPONENT_COUNTS.get( format )
    if size is None:
        raise ValueError( """Unrecognised image format: %r"""%(format,))
    return size

def returnFormat( data, type ):
    """Perform compatibility conversion for PyOpenGL 2.x image-as string results
    
    Uses OpenGL.UNSIGNED_BYTE_IMAGES_AS_STRING to control whether to perform the 
    conversions.
    """
    if _configflags.UNSIGNED_BYTE_IMAGES_AS_STRING:
        if type == _simple.GL_UNSIGNED_BYTE:
            if hasattr( data, 'tobytes' ):
                return data.tobytes()
            elif hasattr( data, 'tostring' ):
                return data.tostring()
            elif hasattr( data, 'raw' ):
                return data.raw 
            elif hasattr( data, '_type_' ):
                s = ctypes.string_at( ctypes.cast( data, ctypes.c_voidp ), ctypes.sizeof( data ))
                result = s[:] # copy into a new string
                return result
    return data


COMPONENT_COUNTS = {
    # Image-format-constant: number-of-components (integer)
}
TYPE_TO_BITS = { 
    # GL-image-storage-type-constant: number-of-bits (integer)
}
TYPE_TO_ARRAYTYPE = { 
    # GL-image-storage-type-constant: GL-datatype (constant)
}
TIGHT_PACK_FORMATS = {
}
RANK_PACKINGS = {
    # rank (integer): list of (function,**arg) to setup for that rank
}



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_MESA_image_dma_buf_export'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_MESA_image_dma_buf_export',error_checker=_errors._error_checker)

@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLImageKHR,ctypes.POINTER(_cs.c_int),arrays.GLintArray,arrays.GLintArray)
def eglExportDMABUFImageMESA(dpy,image,fds,strides,offsets):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLImageKHR,ctypes.POINTER(_cs.c_int),ctypes.POINTER(_cs.c_int),arrays.GLuint64Array)
def eglExportDMABUFImageQueryMESA(dpy,image,fourcc,num_planes,modifiers):pass



'''OpenGL extension EXT.memory_object

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.memory_object to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/memory_object.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.memory_object import *
from OpenGL.raw.GL.EXT.memory_object import _EXTENSION_NAME

def glInitMemoryObjectEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glGetUnsignedBytevEXT.data size not checked against 'pname'
glGetUnsignedBytevEXT=wrapper.wrapper(glGetUnsignedBytevEXT).setInputArraySize(
    'data', None
)
# INPUT glGetUnsignedBytei_vEXT.data size not checked against 'target'
glGetUnsignedBytei_vEXT=wrapper.wrapper(glGetUnsignedBytei_vEXT).setInputArraySize(
    'data', None
)
# INPUT glDeleteMemoryObjectsEXT.memoryObjects size not checked against n
glDeleteMemoryObjectsEXT=wrapper.wrapper(glDeleteMemoryObjectsEXT).setInputArraySize(
    'memoryObjects', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension OES.compressed_ETC1_RGB8_texture

This module customises the behaviour of the 
OpenGL.raw.GLES1.OES.compressed_ETC1_RGB8_texture to provide a more 
Python-friendly API

Overview (from the spec)
	
	The goal of this extension is to allow direct support of
	compressed textures in the Ericsson Texture Compression (ETC)
	formats in OpenGL ES.
	
	ETC-compressed textures are handled in OpenGL ES using the
	CompressedTexImage2D call.
	
	The definition of the "internalformat" parameter in the
	CompressedTexImage2D call has been extended to support
	ETC-compressed textures. 
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/compressed_ETC1_RGB8_texture.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES1 import _types, _glgets
from OpenGL.raw.GLES1.OES.compressed_ETC1_RGB8_texture import *
from OpenGL.raw.GLES1.OES.compressed_ETC1_RGB8_texture import _EXTENSION_NAME

def glInitCompressedEtc1Rgb8TextureOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ARB.explicit_uniform_location

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.explicit_uniform_location to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a method to pre-assign uniform locations to
	uniform variables in the default uniform block, including subroutine
	uniforms. This allows an application to modify the uniform values without
	requiring a GL query like GetUniformLocation, GetSubroutineUniformLocation
	and GetSubroutineIndex.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/explicit_uniform_location.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.explicit_uniform_location import *
from OpenGL.raw.GL.ARB.explicit_uniform_location import _EXTENSION_NAME

def glInitExplicitUniformLocationARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension OES.sample_variables

This module customises the behaviour of the 
OpenGL.raw.GLES2.OES.sample_variables to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows fragment shaders more control over multisample
	rendering. The mask of samples covered by a fragment can be read by
	the shader and individual samples can be masked out. Additionally
	fragment shaders can be run on individual samples and the sample's
	ID and position read to allow better interaction with multisample
	resources such as textures.
	
	In multisample rendering, an implementation is allowed to assign the
	same sets of fragment shader input values to each sample, which then
	allows the optimization where the shader is only evaluated once and
	then distributed to the samples that have been determined to be
	covered by the primitive currently being rasterized. This extension
	does not change how values are interpolated, but it makes some details
	of the current sample available. This means that where these features
	are used (gl_SampleID and gl_SamplePosition), implementations must
	run the fragment shader for each sample.
	
	In order to obtain per-sample interpolation on fragment inputs, either
	OES_sample_shading or OES_shader_multisample_interpolation must
	be used in conjunction with the features from this extension.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/sample_variables.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.OES.sample_variables import *
from OpenGL.raw.GLES2.OES.sample_variables import _EXTENSION_NAME

def glInitSampleVariablesOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.texture_cube_map

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.texture_cube_map to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a new texture generation scheme for cube
	map textures.  Instead of the current texture providing a 1D, 2D,
	or 3D lookup into a 1D, 2D, or 3D texture image, the texture is a
	set of six 2D images representing the faces of a cube.  The (s,t,r)
	texture coordinates are treated as a direction vector emanating from
	the center of a cube.  At texture generation time, the interpolated
	per-fragment (s,t,r) selects one cube face 2D image based on the
	largest magnitude coordinate (the major axis).  A new 2D (s,t) is
	calculated by dividing the two other coordinates (the minor axes
	values) by the major axis value.  Then the new (s,t) is used to
	lookup into the selected 2D texture image face of the cube map.
	
	Unlike a standard 1D, 2D, or 3D texture that have just one target,
	a cube map texture has six targets, one for each of its six 2D texture
	image cube faces.  All these targets must be consistent, complete,
	and have a square dimension.
	
	This extension also provides two new texture coordinate generation modes
	for use in conjunction with cube map texturing.  The reflection map
	mode generates texture coordinates (s,t,r) matching the vertex's
	eye-space reflection vector.  The reflection map mode
	is useful for environment mapping without the singularity inherent
	in sphere mapping.  The normal map mode generates texture coordinates
	(s,t,r) matching the vertex's transformed eye-space
	normal.  The normal map mode is useful for sophisticated cube
	map texturing-based diffuse lighting models.
	
	The intent of the new texgen functionality is that an application using
	cube map texturing can use the new texgen modes to automatically
	generate the reflection or normal vectors used to look up into the
	cube map texture.
	
	An application note:  When using cube mapping with dynamic cube
	maps (meaning the cube map texture is re-rendered every frame),
	by keeping the cube map's orientation pointing at the eye position,
	the texgen-computed reflection or normal vector texture coordinates
	can be always properly oriented for the cube map.  However if the
	cube map is static (meaning that when view changes, the cube map
	texture is not updated), the texture matrix must be used to rotate
	the computed texgen-computed reflection or normal vector texture
	coordinates to match the orientation of the cube map.  The rotation
	can be computed based on two vectors: 1) the direction vector from
	the cube map center to the eye position (both in world coordinates),
	and 2) the cube map orientation in world coordinates.  The axis of
	rotation is the cross product of these two vectors; the angle of
	rotation is the arcsin of the dot product of these two vectors. 

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/texture_cube_map.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.texture_cube_map import *
from OpenGL.raw.GL.EXT.texture_cube_map import _EXTENSION_NAME

def glInitTextureCubeMapEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension OES.shader_multisample_interpolation

This module customises the behaviour of the 
OpenGL.raw.GLES2.OES.shader_multisample_interpolation to provide a more 
Python-friendly API

Overview (from the spec)
	
	In standard multisample rendering, an implementation is allowed to
	assign the same sets of fragment shader input values to each sample.
	This can cause aliasing where the fragment shader input values are
	used to generate a result that doesn't antialias itself, for example
	with alpha-tested transparency.
	
	This extension adds the "sample" qualifier that can be used on vertex
	outputs and fragment inputs. When the "sample" qualifier is used, the
	fragment shader is invoked separately for each covered sample and
	all such qualified interpolants must be evaluated at the corresponding
	sample point.
	
	This extension provides built-in fragment shader functions to provide
	fine-grained control over interpolation, including interpolating a
	fragment shader input at a programmable offset relative to the pixel
	center, a specific sample number, or at the centroid.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/shader_multisample_interpolation.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.OES.shader_multisample_interpolation import *
from OpenGL.raw.GLES2.OES.shader_multisample_interpolation import _EXTENSION_NAME

def glInitShaderMultisampleInterpolationOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.multiview_timer_query

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.multiview_timer_query to provide a more 
Python-friendly API

Overview (from the spec)
	
	OVR_multiview introduced multiview rendering to OpenGL and OpenGL ES.
	This extension removes one of the limitations of the OVR_multiview 
	extension by allowing the use of timer queries during multiview rendering. 
	OVR_multiview does not specify defined behavior for such usage
	(if implemented in OpenGL or if EXT_disjoint_timer_query is present).
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/multiview_timer_query.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.multiview_timer_query import *
from OpenGL.raw.GL.EXT.multiview_timer_query import _EXTENSION_NAME

def glInitMultiviewTimerQueryEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.multiview_tessellation_geometry_shader

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.multiview_tessellation_geometry_shader to provide a more 
Python-friendly API

Overview (from the spec)
	
	OVR_multiview introduced multiview rendering to OpenGL and OpenGL ES.
	
	This extension removes one of the limitations of the OVR_multiview 
	extension by allowing the use of tessellation control, tessellation 
	evaluation, and geometry shaders during multiview rendering. 
	OVR_multiview by itself forbids the use of any of these shader types.
	
	When using tessellation control, tessellation evaluation, and geometry 
	shaders during multiview rendering, any such shader must use the 
	"num_views" layout qualifier provided by the matching shading language 
	extension to specify a view count. The view count specified in these 
	shaders must match the count specified in the vertex shader. Additionally, 
	the shading language extension allows these shaders to use the 
	gl_ViewID_OVR built-in to handle tessellation or geometry shader processing 
	differently for each view.
	
	OVR_multiview2 extends OVR_multiview by allowing view-dependent values
	for any vertex attributes instead of just the position. This new extension
	does not imply the availability of OVR_multiview2, but if both are available,
	view-dependent values for any vertex attributes are also allowed in 
	tessellation control, tessellation evaluation, and geometry shaders.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/multiview_tessellation_geometry_shader.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.multiview_tessellation_geometry_shader import *
from OpenGL.raw.GL.EXT.multiview_tessellation_geometry_shader import _EXTENSION_NAME

def glInitMultiviewTessellationGeometryShaderEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.texture

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.texture to provide a more 
Python-friendly API

Overview (from the spec)
	
	The original intention of this extension was simply to support various
	numeric resolutions of color components in texture images.  While it
	accomplishes this, it also accomplishes a larger task, that of
	formalizing the notion of an internal format for images, corresponding
	to the external format that already existed for image data in host
	memory.  This notion of an internal image format will be used
	extensively in later extensions, especially those concerned with pixel
	manipulation.
	
	The idea of an internal format is simple: rather than treating a
	retained image as having 1, 2, 3, or 4 components, treat it as though
	it has a specific format, such as LUMINANCE_ALPHA, or just ALPHA.  Then
	define the semantics of the use of internal images with these formats in
	a consistent way.  Because texture mapping is already defined in GL, the
	semantics for internal-format images were chosen to match those of the 1,
	2, 3, and 4 component internal images that already existed.  The new
	semantics are a superset of the old ones, however, so this extension
	adds capabilities to GL, as well as allowing internal resolutions to be
	specified.
	
	This extension also defines a robust method for applications to
	determine what combinations of texture dimensions and resolutions are
	supported by an implementation.  It also introduces a new texture
	environment: REPLACE_EXT.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/texture.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.texture import *
from OpenGL.raw.GL.EXT.texture import _EXTENSION_NAME

def glInitTextureEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_alpha_to_coverage_dither_control'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_alpha_to_coverage_dither_control',error_checker=_errors._error_checker)
GL_ALPHA_TO_COVERAGE_DITHER_DEFAULT_NV=_C('GL_ALPHA_TO_COVERAGE_DITHER_DEFAULT_NV',0x934D)
GL_ALPHA_TO_COVERAGE_DITHER_DISABLE_NV=_C('GL_ALPHA_TO_COVERAGE_DITHER_DISABLE_NV',0x934F)
GL_ALPHA_TO_COVERAGE_DITHER_ENABLE_NV=_C('GL_ALPHA_TO_COVERAGE_DITHER_ENABLE_NV',0x934E)
GL_ALPHA_TO_COVERAGE_DITHER_MODE_NV=_C('GL_ALPHA_TO_COVERAGE_DITHER_MODE_NV',0x92BF)
@_f
@_p.types(None,_cs.GLenum)
def glAlphaToCoverageDitherControlNV(mode):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_KHR_debug'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_KHR_debug',error_checker=_errors._error_checker)
EGL_DEBUG_CALLBACK_KHR=_C('EGL_DEBUG_CALLBACK_KHR',0x33B8)
EGL_DEBUG_MSG_CRITICAL_KHR=_C('EGL_DEBUG_MSG_CRITICAL_KHR',0x33B9)
EGL_DEBUG_MSG_ERROR_KHR=_C('EGL_DEBUG_MSG_ERROR_KHR',0x33BA)
EGL_DEBUG_MSG_INFO_KHR=_C('EGL_DEBUG_MSG_INFO_KHR',0x33BC)
EGL_DEBUG_MSG_WARN_KHR=_C('EGL_DEBUG_MSG_WARN_KHR',0x33BB)
EGL_OBJECT_CONTEXT_KHR=_C('EGL_OBJECT_CONTEXT_KHR',0x33B2)
EGL_OBJECT_DISPLAY_KHR=_C('EGL_OBJECT_DISPLAY_KHR',0x33B1)
EGL_OBJECT_IMAGE_KHR=_C('EGL_OBJECT_IMAGE_KHR',0x33B4)
EGL_OBJECT_STREAM_KHR=_C('EGL_OBJECT_STREAM_KHR',0x33B6)
EGL_OBJECT_SURFACE_KHR=_C('EGL_OBJECT_SURFACE_KHR',0x33B3)
EGL_OBJECT_SYNC_KHR=_C('EGL_OBJECT_SYNC_KHR',0x33B5)
EGL_OBJECT_THREAD_KHR=_C('EGL_OBJECT_THREAD_KHR',0x33B0)
@_f
@_p.types(_cs.EGLint,_cs.EGLDEBUGPROCKHR,arrays.EGLAttribArray)
def eglDebugMessageControlKHR(callback,attrib_list):pass
@_f
@_p.types(_cs.EGLint,_cs.EGLDisplay,_cs.EGLenum,_cs.EGLObjectKHR,_cs.EGLLabelKHR)
def eglLabelObjectKHR(display,objectType,object,label):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLint,arrays.EGLAttribArray)
def eglQueryDebugKHR(attribute,value):pass



'''OpenGL extension OES.draw_elements_base_vertex

This module customises the behaviour of the 
OpenGL.raw.GLES2.OES.draw_elements_base_vertex to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a method to specify a "base vertex offset"
	value which is effectively added to every vertex index that is
	transferred through DrawElements.
	
	This mechanism can be used to decouple a set of indices from the
	actual vertex array that it is referencing. This is useful if an
	application stores multiple indexed models in a single vertex array.
	The same index array can be used to draw the model no matter where
	it ends up in a larger vertex array simply by changing the base
	vertex value. Without this functionality, it would be necessary to
	rebind all the vertex attributes every time geometry is switched and
	this can have larger performance penalty.
	
	For example consider the (very contrived and simple) example of
	drawing two triangles to form a quad. In the typical example you
	have the following setup:
	
	      vertices                indices
	     ----------                -----
	  0 | (-1,  1) |            0 |  0  |
	  1 | (-1, -1) |            1 |  1  |
	  2 | ( 1, -1) |            2 |  2  |
	  3 | ( 1,  1) |            3 |  3  |
	     ----------             4 |  0  |
	                            5 |  2  |
	                               -----
	which is normally rendered with the call
	
	   DrawElements(TRIANGLES, 6, UNSIGNED_BYTE, &indices).
	
	Now consider the case where the vertices you want to draw are not at
	the start of a vertex array but are instead located at offset 100
	into a larger array:
	
	       vertices2             indices2
	       ----------             -----
	          ....             0 | 100 |
	  100 | (-1,  1) |         1 | 101 |
	  101 | (-1, -1) |         2 | 102 |
	  102 | ( 1, -1) |         3 | 103 |
	  103 | ( 1,  1) |         4 | 100 |
	          ....             5 | 102 |
	       ----------             -----
	
	The typical choices for rendering this are to rebind your vertex
	attributes with an additional offset of 100*stride, or to create an
	new array of indices (as indices2 in the example). However both
	rebinding vertex attributes and rebuilding index arrays can be quite
	costly activities.
	
	With the new drawing commands introduced by this extension you can
	instead draw using vertices2 and the new draw call:
	
	   DrawElementsBaseVertexOES(TRIANGLES, 6, UNSIGNED_BYTE, &indices, 100)

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/draw_elements_base_vertex.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.OES.draw_elements_base_vertex import *
from OpenGL.raw.GLES2.OES.draw_elements_base_vertex import _EXTENSION_NAME

def glInitDrawElementsBaseVertexOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glDrawElementsBaseVertexOES.indices size not checked against 'count,type'
glDrawElementsBaseVertexOES=wrapper.wrapper(glDrawElementsBaseVertexOES).setInputArraySize(
    'indices', None
)
# INPUT glDrawRangeElementsBaseVertexOES.indices size not checked against 'count,type'
glDrawRangeElementsBaseVertexOES=wrapper.wrapper(glDrawRangeElementsBaseVertexOES).setInputArraySize(
    'indices', None
)
# INPUT glDrawElementsInstancedBaseVertexOES.indices size not checked against 'count,type'
glDrawElementsInstancedBaseVertexOES=wrapper.wrapper(glDrawElementsInstancedBaseVertexOES).setInputArraySize(
    'indices', None
)
# INPUT glMultiDrawElementsBaseVertexEXT.basevertex size not checked against 'drawcount'
# INPUT glMultiDrawElementsBaseVertexEXT.count size not checked against 'drawcount'
# INPUT glMultiDrawElementsBaseVertexEXT.indices size not checked against 'drawcount'
glMultiDrawElementsBaseVertexEXT=wrapper.wrapper(glMultiDrawElementsBaseVertexEXT).setInputArraySize(
    'basevertex', None
).setInputArraySize(
    'count', None
).setInputArraySize(
    'indices', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension NV.uniform_buffer_unified_memory

This module customises the behaviour of the 
OpenGL.raw.GL.NV.uniform_buffer_unified_memory to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a mechanism to specify uniform buffers
	using GPU addresses.
	
	Binding uniform buffers is one of the most frequent and expensive
	operations in many GL applications, due to the cost of chasing 
	pointers and binding objects described in the overview of 
	NV_shader_buffer_load. The intent of this extension is to enable a 
	way for the application to specify uniform buffer state that alleviates
	the overhead of object binds and driver memory management.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/uniform_buffer_unified_memory.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.uniform_buffer_unified_memory import *
from OpenGL.raw.GL.NV.uniform_buffer_unified_memory import _EXTENSION_NAME

def glInitUniformBufferUnifiedMemoryNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension SGIX.polynomial_ffd

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.polynomial_ffd to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds the capability to alter vertex coordinates,  the
	corresponding normal coordinates, and texture coordinates based on a
	client-specified trivariate polynomial functions.  These functions may be
	thought of as a warping of object/texture space (or, alternatively, as a
	warping of the object embedded in object/texture space).
	
	Deformations of space are used for a variety of modeling effects, including
	character animation.  The deformation specified in this extension is one of
	a variety of mappings that have been proposed.
	
	Only 3D to 3D deformation are considered.   We shall not consider
	homogeneous deformations.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/polynomial_ffd.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIX.polynomial_ffd import *
from OpenGL.raw.GL.SGIX.polynomial_ffd import _EXTENSION_NAME

def glInitPolynomialFfdSGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glDeformationMap3dSGIX.points size not checked against 'target,ustride,uorder,vstride,vorder,wstride,worder'
glDeformationMap3dSGIX=wrapper.wrapper(glDeformationMap3dSGIX).setInputArraySize(
    'points', None
)
# INPUT glDeformationMap3fSGIX.points size not checked against 'target,ustride,uorder,vstride,vorder,wstride,worder'
glDeformationMap3fSGIX=wrapper.wrapper(glDeformationMap3fSGIX).setInputArraySize(
    'points', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension KHR.no_error

This module customises the behaviour of the 
OpenGL.raw.GL.KHR.no_error to provide a more 
Python-friendly API

Overview (from the spec)
	
	With this extension enabled any behavior that generates a GL error will
	have undefined behavior.  The reason this extension exists is performance
	can be increased and power usage decreased.  When this mode is used, a GL
	driver can have undefined behavior where it would have generated a GL error
	without this extension.  This could include application termination.  In
	general this extension should be used after you have verified all the GL
	errors are removed, and an application is not the kind that would check
	for GL errors and adjust behavior based on those errors.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/KHR/no_error.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.KHR.no_error import *
from OpenGL.raw.GL.KHR.no_error import _EXTENSION_NAME

def glInitNoErrorKHR():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_blend_minmax_factor'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_blend_minmax_factor',error_checker=_errors._error_checker)
GL_FACTOR_MAX_AMD=_C('GL_FACTOR_MAX_AMD',0x901D)
GL_FACTOR_MIN_AMD=_C('GL_FACTOR_MIN_AMD',0x901C)




'''OpenGL extension OES.draw_buffers_indexed

This module customises the behaviour of the 
OpenGL.raw.GLES2.OES.draw_buffers_indexed to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension builds upon the EXT_draw_buffers extension.
	In EXT_draw_buffers (part of OpenGL ES 3.0), separate values could
	be written to each color buffer, but the blend enable, blend functions,
	blend equations and color write masks are global and apply to all color
	outputs.
	
	This extension provides the ability to independently
	  * enable or disable blending,
	  * set the blend equations,
	  * set the blend functions, and
	  * set the color write masks
	per color output.
	
	This extension introduces indexed versions of the enable,
	blend equation, blend function, and color mask commands, as
	well as associated indexed queries in order to control and
	query these states independently on a per-color output basis.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/draw_buffers_indexed.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.OES.draw_buffers_indexed import *
from OpenGL.raw.GLES2.OES.draw_buffers_indexed import _EXTENSION_NAME

def glInitDrawBuffersIndexedOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension OES.texture_cube_map_array

This module customises the behaviour of the 
OpenGL.raw.GLES2.OES.texture_cube_map_array to provide a more 
Python-friendly API

Overview (from the spec)
	
	OpenGL ES 3.1 supports two-dimensional array textures. An array texture
	is an ordered set of images with the same size and format. Each image in
	an array texture has a unique level. This extension expands texture
	array support to include cube map textures.
	
	A cube map array texture is a two-dimensional array texture that may
	contain many cube map layers. Each cube map layer is a unique cube map
	image set. Images in a cube map array have the same size and format
	limitations as two-dimensional array textures. A cube map array texture
	is specified using TexImage3D or TexStorage3D in a similar manner to
	two-dimensional arrays. Cube map array textures can be bound to a render
	targets of a frame buffer object just as two-dimensional arrays are,
	using FramebufferTextureLayer.
	
	When accessed by a shader, a cube map array texture acts as a single
	unit. The "s", "t", "r" texture coordinates are treated as a regular
	cube map texture fetch. The "q" texture is treated as an unnormalized
	floating-point value identifying the layer of the cube map array
	texture. Cube map array texture lookups do not filter between layers.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/texture_cube_map_array.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.OES.texture_cube_map_array import *
from OpenGL.raw.GLES2.OES.texture_cube_map_array import _EXTENSION_NAME

def glInitTextureCubeMapArrayOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension QCOM.tiled_rendering

This module customises the behaviour of the 
OpenGL.raw.GLES2.QCOM.tiled_rendering to provide a more 
Python-friendly API

Overview (from the spec)
	
	In the handheld graphics space, a typical challenge is achieving efficient
	rendering performance given the different characteristics of the various
	types of graphics memory.  Some types of memory ("slow" memory) are less
	expensive but have low bandwidth, higher latency, and/or higher power
	consumption, while other types ("fast" memory) are more expensive but have
	higher bandwidth, lower latency, and/or lower power consumption.  In many
	cases, it is more efficient for a graphics processing unit (GPU) to render
	directly to fast memory, but at most common display resolutions it is not
	practical for a device to contain enough fast memory to accommodate both the
	full color and depth/stencil buffers (the frame buffer).  In some devices,
	this problem can be addressed by providing both types of memory; a large
	amount of slow memory that is sufficient to store the entire frame buffer,
	and a small, dedicated amount of fast memory that allows the GPU to render
	with optimal performance.  The challenge lies in finding a way for the GPU
	to render to fast memory when it is not large enough to contain the actual
	frame buffer.
	
	One approach to solving this problem is to design the GPU and/or driver
	using a tiled rendering architecture.  With this approach the render target
	is subdivided into a number of individual tiles, which are sized to fit
	within the available amount of fast memory.  Under normal operation, the
	entire scene will be rendered to each individual tile using a multi-pass
	technique, in which primitives that lie entirely outside of the tile being
	rendered are trivially discarded.  After each tile has been rendered, its
	contents are saved out to the actual frame buffer in slow memory (a process
	referred to as the "resolve").  The resolve introduces significant overhead,
	both for the CPU and the GPU.  However, even with this additional overhead,
	rendering using this method is usually more efficient than rendering
	directly to slow memory.
	
	This extension allows the application to specify a rectangular tile
	rendering area and have full control over the resolves for that area.  The
	information given to the driver through this API can be used to perform
	various optimizations in the driver and hardware.  One example optimization
	is being able to reduce the size or number of the resolves.  Another
	optimization might be to reduce the number of passes needed in the tiling
	approach mentioned above.  Even traditional rendering GPUs that don't use
	tiles may benefit from this extension depending on their implemention of
	certain common GPU operations.
	
	One typical use case could involve an application only rendering to select
	portions of the render target using this technique (which shall be referred
	to as "application tiling"), leaving all other portions of the render target
	untouched.  Therefore, in order to preserve the contents of the untouched
	portions of the render target, the application must request an EGL (or other
	context management API) configuration with a non-destructive swap. A
	destructive swap may only be used safely if the application renders to the
	entire area of the render target during each frame (otherwise the contents
	of the untouched portions of the frame buffer will be undefined).
	
	Additionally, care must be taken to avoid the cost of mixing rendering with
	and without application tiling within a single frame.  Rendering without
	application tiling ("normal" rendering) is most efficient when all of the
	rendering for the entire scene can be encompassed within a single resolve.
	If any portions of the scene are rendered prior to that resolve (such as via
	a prior resolve, or via application tiling), then that resolve becomes much
	more heavyweight.  When this occurs, prior to rendering each tile the fast
	memory must be populated with the existing contents of the frame buffer
	region corresponding to that tile.  This operation can double the cost of
	resolves, so it is recommended that applications avoid mixing application
	tiling and normal rendering within a single frame.  If both rendering
	methods must be used in the same frame, then the most efficient approach is
	to perform all normal rendering first, followed by rendering done with
	application tiling.  An implicit resolve will occur (if needed) at the start
	of application tiling, so any pending normal rendering operations will be
	flushed at the time application tiling is initiated.  This extension
	provides interfaces for the application to communicate to the driver whether
	or not rendering done with application tiling depends on the existing
	contents of the specified tile, and whether or not the rendered contents of
	the specified tile need to be preserved upon completion.  This mechanism can
	be used to obtain optimal performance, e.g. when the application knows that
	every pixel in a tile will be completely rendered or when the resulting
	contents of the depth/stencil buffers do not need to be preserved.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/QCOM/tiled_rendering.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.QCOM.tiled_rendering import *
from OpenGL.raw.GLES2.QCOM.tiled_rendering import _EXTENSION_NAME

def glInitTiledRenderingQCOM():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_command_list'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_command_list',error_checker=_errors._error_checker)
GL_ALPHA_REF_COMMAND_NV=_C('GL_ALPHA_REF_COMMAND_NV',0x000F)
GL_ATTRIBUTE_ADDRESS_COMMAND_NV=_C('GL_ATTRIBUTE_ADDRESS_COMMAND_NV',0x0009)
GL_BLEND_COLOR_COMMAND_NV=_C('GL_BLEND_COLOR_COMMAND_NV',0x000B)
GL_DRAW_ARRAYS_COMMAND_NV=_C('GL_DRAW_ARRAYS_COMMAND_NV',0x0003)
GL_DRAW_ARRAYS_INSTANCED_COMMAND_NV=_C('GL_DRAW_ARRAYS_INSTANCED_COMMAND_NV',0x0007)
GL_DRAW_ARRAYS_STRIP_COMMAND_NV=_C('GL_DRAW_ARRAYS_STRIP_COMMAND_NV',0x0005)
GL_DRAW_ELEMENTS_COMMAND_NV=_C('GL_DRAW_ELEMENTS_COMMAND_NV',0x0002)
GL_DRAW_ELEMENTS_INSTANCED_COMMAND_NV=_C('GL_DRAW_ELEMENTS_INSTANCED_COMMAND_NV',0x0006)
GL_DRAW_ELEMENTS_STRIP_COMMAND_NV=_C('GL_DRAW_ELEMENTS_STRIP_COMMAND_NV',0x0004)
GL_ELEMENT_ADDRESS_COMMAND_NV=_C('GL_ELEMENT_ADDRESS_COMMAND_NV',0x0008)
GL_FRONT_FACE_COMMAND_NV=_C('GL_FRONT_FACE_COMMAND_NV',0x0012)
GL_LINE_WIDTH_COMMAND_NV=_C('GL_LINE_WIDTH_COMMAND_NV',0x000D)
GL_NOP_COMMAND_NV=_C('GL_NOP_COMMAND_NV',0x0001)
GL_POLYGON_OFFSET_COMMAND_NV=_C('GL_POLYGON_OFFSET_COMMAND_NV',0x000E)
GL_SCISSOR_COMMAND_NV=_C('GL_SCISSOR_COMMAND_NV',0x0011)
GL_STENCIL_REF_COMMAND_NV=_C('GL_STENCIL_REF_COMMAND_NV',0x000C)
GL_TERMINATE_SEQUENCE_COMMAND_NV=_C('GL_TERMINATE_SEQUENCE_COMMAND_NV',0x0000)
GL_UNIFORM_ADDRESS_COMMAND_NV=_C('GL_UNIFORM_ADDRESS_COMMAND_NV',0x000A)
GL_VIEWPORT_COMMAND_NV=_C('GL_VIEWPORT_COMMAND_NV',0x0010)
@_f
@_p.types(None,_cs.GLuint)
def glCallCommandListNV(list):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint)
def glCommandListSegmentsNV(list,segments):pass
@_f
@_p.types(None,_cs.GLuint)
def glCompileCommandListNV(list):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glCreateCommandListsNV(n,lists):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glCreateStatesNV(n,states):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteCommandListsNV(n,lists):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteStatesNV(n,states):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuint64Array,arrays.GLsizeiArray,_cs.GLuint)
def glDrawCommandsAddressNV(primitiveMode,indirects,sizes,count):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,ctypes.POINTER(_cs.GLintptr),arrays.GLsizeiArray,_cs.GLuint)
def glDrawCommandsNV(primitiveMode,buffer,indirects,sizes,count):pass
@_f
@_p.types(None,arrays.GLuint64Array,arrays.GLsizeiArray,arrays.GLuintArray,arrays.GLuintArray,_cs.GLuint)
def glDrawCommandsStatesAddressNV(indirects,sizes,states,fbos,count):pass
@_f
@_p.types(None,_cs.GLuint,ctypes.POINTER(_cs.GLintptr),arrays.GLsizeiArray,arrays.GLuintArray,arrays.GLuintArray,_cs.GLuint)
def glDrawCommandsStatesNV(buffer,indirects,sizes,states,fbos,count):pass
@_f
@_p.types(_cs.GLuint,_cs.GLenum,_cs.GLuint)
def glGetCommandHeaderNV(tokenID,size):pass
@_f
@_p.types(_cs.GLushort,_cs.GLenum)
def glGetStageIndexNV(shadertype):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsCommandListNV(list):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsStateNV(state):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,arrays.GLvoidpArray,arrays.GLsizeiArray,arrays.GLuintArray,arrays.GLuintArray,_cs.GLuint)
def glListDrawCommandsStatesClientNV(list,segment,indirects,sizes,states,fbos,count):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum)
def glStateCaptureNV(state,mode):pass



'''OpenGL extension OES.byte_coordinates

This module customises the behaviour of the 
OpenGL.raw.GL.OES.byte_coordinates to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows specifying, additionally to all existing 
	values, byte-valued vertex and texture coordinates to be used.
	
	The main reason for introducing the byte-argument is to allow 
	storing data more compactly on memory-restricted environments.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/byte_coordinates.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.OES.byte_coordinates import *
from OpenGL.raw.GL.OES.byte_coordinates import _EXTENSION_NAME

def glInitByteCoordinatesOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glMultiTexCoord1bvOES=wrapper.wrapper(glMultiTexCoord1bvOES).setInputArraySize(
    'coords', 1
)
glMultiTexCoord2bvOES=wrapper.wrapper(glMultiTexCoord2bvOES).setInputArraySize(
    'coords', 2
)
glMultiTexCoord3bvOES=wrapper.wrapper(glMultiTexCoord3bvOES).setInputArraySize(
    'coords', 3
)
glMultiTexCoord4bvOES=wrapper.wrapper(glMultiTexCoord4bvOES).setInputArraySize(
    'coords', 4
)
glTexCoord1bvOES=wrapper.wrapper(glTexCoord1bvOES).setInputArraySize(
    'coords', 1
)
glTexCoord2bvOES=wrapper.wrapper(glTexCoord2bvOES).setInputArraySize(
    'coords', 2
)
glTexCoord3bvOES=wrapper.wrapper(glTexCoord3bvOES).setInputArraySize(
    'coords', 3
)
glTexCoord4bvOES=wrapper.wrapper(glTexCoord4bvOES).setInputArraySize(
    'coords', 4
)
glVertex2bvOES=wrapper.wrapper(glVertex2bvOES).setInputArraySize(
    'coords', 2
)
glVertex3bvOES=wrapper.wrapper(glVertex3bvOES).setInputArraySize(
    'coords', 3
)
glVertex4bvOES=wrapper.wrapper(glVertex4bvOES).setInputArraySize(
    'coords', 4
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES1 import _types as _cs
# End users want this...
from OpenGL.raw.GLES1._types import *
from OpenGL.raw.GLES1 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES1_EXT_debug_marker'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES1,'GLES1_EXT_debug_marker',error_checker=_errors._error_checker)

@_f
@_p.types(None,_cs.GLsizei,arrays.GLcharArray)
def glInsertEventMarkerEXT(length,marker):pass
@_f
@_p.types(None,)
def glPopGroupMarkerEXT():pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLcharArray)
def glPushGroupMarkerEXT(length,marker):pass



'''OpenGL extension OES.fbo_render_mipmap

This module customises the behaviour of the 
OpenGL.raw.GLES1.OES.fbo_render_mipmap to provide a more 
Python-friendly API

Overview (from the spec)
	
	OES_framebuffer_object allows rendering to the base level of a 
	texture only.  This extension removes this limitation by 
	allowing implementations to support rendering to any mip-level
	of a texture(s) that is attached to a framebuffer object(s).
	
	If this extension is supported, FramebufferTexture2DOES, and
	FramebufferTexture3DOES can be used to render directly into 
	any mip level of a texture image

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/fbo_render_mipmap.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES1 import _types, _glgets
from OpenGL.raw.GLES1.OES.fbo_render_mipmap import *
from OpenGL.raw.GLES1.OES.fbo_render_mipmap import _EXTENSION_NAME

def glInitFboRenderMipmapOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


"""Exceptional cases that need some extra wrapping"""
from OpenGL import arrays
from OpenGL.arrays.arraydatatype import GLfloatArray
from OpenGL.lazywrapper import lazy as _lazy
from OpenGL.GL.VERSION import GL_1_1 as full
from OpenGL.raw.GL import _errors
from OpenGL._bytes import bytes
from OpenGL import _configflags
from OpenGL._null import NULL as _NULL
import ctypes

__all__ = [
    'glBegin',
    'glCallLists',
    'glColor',
    'glDeleteTextures',
    'glEnd',
    'glMap1d',
    'glMap1f',
    'glMap2d',
    'glMap2f',
    'glMaterial',
    'glRasterPos',
    'glTexParameter',
    'glVertex',
    'glAreTexturesResident',
]

glRasterPosDispatch = {
    2: full.glRasterPos2d,
    3: full.glRasterPos3d,
    4: full.glRasterPos4d,
}

if _configflags.ERROR_CHECKING:
    @_lazy( full.glBegin )
    def glBegin( baseFunction, mode ):
        """Begin GL geometry-definition mode, disable automatic error checking"""
        _errors._error_checker.onBegin( )
        return baseFunction( mode )
    @_lazy( full.glEnd )
    def glEnd( baseFunction ):
        """Finish GL geometry-definition mode, re-enable automatic error checking"""
        _errors._error_checker.onEnd( )
        return baseFunction( )
else:
    glBegin = full.glBegin
    glEnd = full.glEnd

@_lazy( full.glDeleteTextures )
def glDeleteTextures( baseFunction, size, array=_NULL ):
    """Delete specified set of textures
    
    If array is *not* passed then `size` must be a `GLuintArray`
    compatible object which can be sized using `arraySize`, the 
    result of which will be used as size.
    """
    if array is _NULL:
        ptr = arrays.GLuintArray.asArray( size )
        size = arrays.GLuintArray.arraySize( ptr )
    else:
        ptr = array
    return baseFunction( size, ptr )


def glMap2( baseFunction, arrayType ):
    def glMap2( target, u1, u2, v1, v2, points):
        """glMap2(target, u1, u2, v1, v2, points[][][]) -> None

        This is a completely non-standard signature which doesn't allow for most
        of the funky uses with strides and the like, but it has been like this for
        a very long time...
        """
        ptr = arrayType.asArray( points )
        uorder,vorder,vstride = arrayType.dimensions( ptr )
        ustride = vstride*vorder
        return baseFunction(
            target,
            u1, u2,
            ustride, uorder,
            v1, v2,
            vstride, vorder,
            ptr
        )
    glMap2.__name__ = baseFunction.__name__
    glMap2.baseFunction = baseFunction
    return glMap2
glMap2d = glMap2( full.glMap2d, arrays.GLdoubleArray )
glMap2f = glMap2( full.glMap2f, arrays.GLfloatArray )
try:
    del glMap2
except NameError as err:
    pass

def glMap1( baseFunction, arrayType ):
    def glMap1(target,u1,u2,points):
        """glMap1(target, u1, u2, points[][][]) -> None

        This is a completely non-standard signature which doesn't allow for most
        of the funky uses with strides and the like, but it has been like this for
        a very long time...
        """
        ptr = arrayType.asArray( points )
        dims = arrayType.dimensions( ptr )
        uorder = dims[0]
        ustride = dims[1]
        return baseFunction( target, u1,u2,ustride,uorder, ptr )
    glMap1.__name__ == baseFunction.__name__
    glMap1.baseFunction = baseFunction
    return glMap1
glMap1d = glMap1( full.glMap1d, arrays.GLdoubleArray )
glMap1f = glMap1( full.glMap1f, arrays.GLfloatArray )
try:
    del glMap1
except NameError as err:
    pass

def glRasterPos( *args ):
    """Choose glRasterPosX based on number of args"""
    if len(args) == 1:
        # v form...
        args = args[0]
    function = glRasterPosDispatch[ len(args) ]
    return function( *args )

glVertexDispatch = {
    2: full.glVertex2d,
    3: full.glVertex3d,
    4: full.glVertex4d,
}
def glVertex( *args ):
    """Choose glVertexX based on number of args"""
    if len(args) == 1:
        # v form...
        args = args[0]
    return glVertexDispatch[ len(args) ]( *args )

@_lazy( full.glCallLists )
def glCallLists( baseFunction, lists, *args ):
    """glCallLists( bytes( lists ) or lists[] ) -> None

    Restricted version of glCallLists, takes a string or a GLuint compatible
    array data-type and passes into the base function.
    """
    if not len(args):
        if isinstance( lists, bytes ):
            return baseFunction(
                len(lists),
                full.GL_UNSIGNED_BYTE,
                ctypes.c_void_p(arrays.GLubyteArray.dataPointer( lists )),
            )
        ptr = arrays.GLuintArray.asArray( lists )
        size = arrays.GLuintArray.arraySize( ptr )
        return baseFunction(
            size,
            full.GL_UNSIGNED_INT,
            ctypes.c_void_p( arrays.GLuintArray.dataPointer(ptr))
        )
    return baseFunction( lists, *args )

def glTexParameter( target, pname, parameter ):
    """Set a texture parameter, choose underlying call based on pname and parameter"""
    if isinstance( parameter, float ):
        return full.glTexParameterf( target, pname, parameter )
    elif isinstance( parameter, int ):
        return full.glTexParameteri( target, pname, parameter )
    else:
        value = GLfloatArray.asArray( parameter, full.GL_FLOAT )
        return full.glTexParameterfv( target, pname, value )

def glMaterial( faces, constant, *args ):
    """glMaterial -- convenience function to dispatch on argument type

    If passed a single argument in args, calls:
        glMaterialfv( faces, constant, args[0] )
    else calls:
        glMaterialf( faces, constant, *args )
    """
    if len(args) == 1:
        arg = GLfloatArray.asArray( args[0] )
        if arg is None:
            raise ValueError( """Null value in glMaterial: %s"""%(args,) )
        return full.glMaterialfv( faces, constant, arg )
    else:
        return full.glMaterialf( faces, constant, *args )

glColorDispatch = {
    3: full.glColor3fv,
    4: full.glColor4fv,
}

def glColor( *args ):
    """glColor*f* -- convenience function to dispatch on argument type

    dispatches to glColor3f, glColor2f, glColor4f, glColor3f, glColor2f, glColor4f
    depending on the arguments passed...
    """
    arglen = len(args)
    if arglen == 1:
        arg = arrays.GLfloatArray.asArray( args[0] )
        function = glColorDispatch[arrays.GLfloatArray.arraySize( arg )]
        return function( arg )
    elif arglen == 2:
        return full.glColor2d( *args )
    elif arglen == 3:
        return full.glColor3d( *args )
    elif arglen == 4:
        return full.glColor4d( *args )
    else:
        raise ValueError( """Don't know how to handle arguments: %s"""%(args,))


# Rectagle coordinates,
@_lazy( full.glAreTexturesResident )
def glAreTexturesResident( baseFunction, *args ):
    """Allow both Pythonic and C-style calls to glAreTexturesResident

        glAreTexturesResident( arrays.GLuintArray( textures) )

    or

        glAreTexturesResident( int(n), arrays.GLuintArray( textures), arrays.GLuboolean( output) )

    or

        glAreTexturesResident( int(n), arrays.GLuintArray( textures) )

    returns the output arrays.GLubooleanArray
    """
    if len(args) == 1:
        # Pythonic form...
        textures = args[0]
        textures = arrays.GLuintArray.asArray( textures )
        n = arrays.GLuintArray.arraySize(textures)
        output = arrays.GLbooleanArray.zeros( (n,))
    elif len(args) == 2:
        try:
            n = int( args[0] )
        except TypeError:
            textures = args[0]
            textures = arrays.GLuintArray.asArray( textures )

            n = arrays.GLuintArray.arraySize(textures)
            output = args[1]
            output = arrays.GLbooleanArray.asArray( output )
        else:
            textures = args[1]
            textures = arrays.GLuintArray.asArray( textures )

            output = arrays.GLbooleanArray.zeros( (n,))
    elif len(args) == 3:
        n,textures,output = args
        textures = arrays.GLuintArray.asArray( textures )
        output = arrays.GLbooleanArray.asArray( output )
    else:
        raise TypeError( """Expected 1 to 3 arguments to glAreTexturesResident""" )
    texturePtr = arrays.GLuintArray.typedPointer( textures )
    outputPtr = arrays.GLbooleanArray.typedPointer( output )
    result = baseFunction( n, texturePtr, outputPtr )
    if result:
        # weirdness of the C api, doesn't produce values if all are true
        for i in range(len(output)):
            output[i] = 1
    return output



'''OpenGL extension OVR.multiview2

This module customises the behaviour of the 
OpenGL.raw.GL.OVR.multiview2 to provide a more 
Python-friendly API

Overview (from the spec)
	
	
	This extension relaxes the restriction in OVR_multiview that only gl_Position
	can depend on ViewID in the vertex shader.  With this change, view-dependent
	outputs like reflection vectors and similar are allowed.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OVR/multiview2.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.OVR.multiview2 import *
from OpenGL.raw.GL.OVR.multiview2 import _EXTENSION_NAME

def glInitMultiview2OVR():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.conservative_raster_pre_snap

This module customises the behaviour of the 
OpenGL.raw.GL.NV.conservative_raster_pre_snap to provide a more 
Python-friendly API

Overview (from the spec)
	
	NV_conservative_raster_pre_snap_triangles provides a new mode to achieve
	rasterization of triangles that is conservative w.r.t the triangle at 
	infinite precision i.e. before it is snapped to the sub-pixel grid.  This
	extension provides a new mode that expands this functionality to lines and 
	points.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/conservative_raster_pre_snap.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.conservative_raster_pre_snap import *
from OpenGL.raw.GL.NV.conservative_raster_pre_snap import _EXTENSION_NAME

def glInitConservativeRasterPreSnapNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.pixel_buffer_object

This module customises the behaviour of the 
OpenGL.raw.GLES2.NV.pixel_buffer_object to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension permits buffer objects to be used not only with vertex
	array data, but also with pixel data.  The intent is to provide more
	acceleration opportunities for OpenGL pixel commands.
	
	While a single buffer object can be bound for both vertex arrays and
	pixel commands, we use the designations vertex buffer object (VBO)
	and pixel buffer object (PBO) to indicate their particular usage in
	a given situation.
	
	This extension does not add any new functionality to buffer objects
	themselves.  It simply adds two new targets to which buffer objects
	can be bound: GL_PIXEL_PACK_BUFFER_NV and GL_PIXEL_UNPACK_BUFFER_NV.
	When a buffer object is bound to the GL_PIXEL_PACK_BUFFER_NV target,
	commands such as glReadPixels pack (write) their data into a buffer
	object. When a buffer object is bound to the GL_PIXEL_UNPACK_BUFFER_NV
	target, commands such as glTexImage2D unpack (read) their
	data from a buffer object.
	
	There are a several approaches to improve graphics performance
	with PBOs.  Some of the most interesting approaches are:
	
	- Streaming texture updates:  If the application uses
	  glMapBufferOES/glMapBufferRangeEXT/glUnmapBufferOES to write
	  its data for glTexSubImage into a buffer object, at least one of
	  the data copies usually required to download a texture can be
	  eliminated, significantly increasing texture download performance.
	
	- Asynchronous glReadPixels:  If an application needs to read back a
	  number of images and process them with the CPU, the existing GL
	  interface makes it nearly impossible to pipeline this operation.
	  The driver will typically send the hardware a readback command
	  when glReadPixels is called, and then wait for all of the data to
	  be available before returning control to the application.  Then,
	  the application can either process the data immediately or call
	  glReadPixels again; in neither case will the readback overlap with
	  the processing.  If the application issues several readbacks
	  into several buffer objects, however, and then maps each one to
	  process its data, then the readbacks can proceed in parallel with
	  the data processing.
	
	- Render to vertex array:  The application can use a fragment
	  program to render some image into one of its buffers, then read
	  this image out into a buffer object via glReadPixels.  Then, it can
	  use this buffer object as a source of vertex data.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/pixel_buffer_object.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.NV.pixel_buffer_object import *
from OpenGL.raw.GLES2.NV.pixel_buffer_object import _EXTENSION_NAME

def glInitPixelBufferObjectNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ARB.texture_env_crossbar

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.texture_env_crossbar to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds the capability to use the texture color from
	other texture units as sources to the COMBINE_ARB enviornment
	function. The ARB_texture_env_combine extension defined texture 
	enviornment functions which could use the color from the 
	current texture unit as a source. This extension adds
	the ability to use the color from any texture unit as a source.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/texture_env_crossbar.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.texture_env_crossbar import *
from OpenGL.raw.GL.ARB.texture_env_crossbar import _EXTENSION_NAME

def glInitTextureEnvCrossbarARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.buffer_storage

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.buffer_storage to provide a more 
Python-friendly API

Overview (from the spec)
	
	OpenGL ES has long supported buffer objects as a means of storing data
	that may be used to source vertex attributes, pixel data for textures,
	uniforms and other elements. In un-extended ES, buffer data stores
	are mutable - that is, they may be de-allocated or resized while they
	are in use. The GL_EXT_texture_storage extension added immutable storage
	for texture objects (and was subsequently incorporated into OpenGL ES 3.0).
	This extension further applies the concept of immutable storage to
	buffer objects. If an implementation is aware of a buffer's immutability,
	it may be able to make certain assumptions or apply particular
	optimizations in order to increase performance or reliability.
	
	Furthermore, this extension allows applications to pass additional
	information about a requested allocation to the implementation which it
	may use to select memory heaps, caching behavior or allocation strategies.
	
	Finally, this extension introduces the concept of persistent client
	mappings of buffer objects, which allow clients to retain pointers to a
	buffer's data store returned as the result of a mapping, and to issue
	drawing commands while those mappings are in place.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/buffer_storage.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.buffer_storage import *
from OpenGL.raw.GLES2.EXT.buffer_storage import _EXTENSION_NAME

def glInitBufferStorageEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glBufferStorageEXT.data size not checked against size
glBufferStorageEXT=wrapper.wrapper(glBufferStorageEXT).setInputArraySize(
    'data', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension OES.vertex_half_float

This module customises the behaviour of the 
OpenGL.raw.GLES2.OES.vertex_half_float to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds a 16-bit floating pt data type (aka half float) 
	to vertex data specified using vertex arrays.  The 16-bit floating-point
	components have 1 sign bit, 5 exponent bits, and 10 mantissa bits.
	
	The half float data type can be very useful in specifying vertex attribute 
	data such as color, normals, texture coordinates etc.  By using half floats 
	instead of floats, we reduce the memory requirements by half.  Not only does 
	the memory footprint reduce by half, but the memory bandwidth required for
	vertex transformations also reduces by the same amount approximately.
	Another advantage of using half floats over short/byte data types is that we 
	do not needto scale the data.  For example, using SHORT for texture coordinates 
	implies that we need to scale the input texture coordinates in the shader or 
	set an appropriate scale matrix as the texture matrix for fixed function pipeline.
	Doing these additional scaling operations impacts vertex transformation
	performance.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/vertex_half_float.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.OES.vertex_half_float import *
from OpenGL.raw.GLES2.OES.vertex_half_float import _EXTENSION_NAME

def glInitVertexHalfFloatOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_NV_stream_consumer_gltexture_yuv'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_NV_stream_consumer_gltexture_yuv',error_checker=_errors._error_checker)
EGL_YUV_BUFFER_EXT=_C('EGL_YUV_BUFFER_EXT',0x3300)
EGL_YUV_NUMBER_OF_PLANES_EXT=_C('EGL_YUV_NUMBER_OF_PLANES_EXT',0x3311)
EGL_YUV_PLANE0_TEXTURE_UNIT_NV=_C('EGL_YUV_PLANE0_TEXTURE_UNIT_NV',0x332C)
EGL_YUV_PLANE1_TEXTURE_UNIT_NV=_C('EGL_YUV_PLANE1_TEXTURE_UNIT_NV',0x332D)
EGL_YUV_PLANE2_TEXTURE_UNIT_NV=_C('EGL_YUV_PLANE2_TEXTURE_UNIT_NV',0x332E)
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLStreamKHR,_cs.EGLAttrib)
def eglStreamConsumerGLTextureExternalAttribsNV(dpy,stream,*attrib_list):pass



'''OpenGL extension ARB.texture_rectangle

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.texture_rectangle to provide a more 
Python-friendly API

Overview (from the spec)
	
	OpenGL texturing is limited to images with power-of-two dimensions
	and an optional 1-texel border.  The ARB_texture_rectangle extension
	adds a new texture target that supports 2D textures without requiring
	power-of-two dimensions.
	
	Non-power-of-two sized (NPOTS) textures are useful for storing video
	images that do not have power-of-two sized (POTS).  Re-sampling
	artifacts are avoided and less texture memory may be required by
	using non-power-of-two sized textures.  Non-power-of-two sized
	textures are also useful for shadow maps and window-space texturing.
	
	However, non-power-of-two sized textures have limitations that
	do not apply to power-of-two sized textures.  NPOTS textures may
	not use mipmap filtering; POTS textures support both mipmapped
	and non-mipmapped filtering.  NPOTS textures support only the
	GL_CLAMP, GL_CLAMP_TO_EDGE, and GL_CLAMP_TO_BORDER wrap modes;
	POTS textures support GL_CLAMP_TO_EDGE, GL_REPEAT, GL_CLAMP,
	GL_MIRRORED_REPEAT, and GL_CLAMP_TO_BORDER (and GL_MIRROR_CLAMP_ATI
	and GL_MIRROR_CLAMP_TO_EDGE_ATI if ATI_texture_mirror_once is
	supported) .  NPOTS textures do not support an optional 1-texel
	border; POTS textures do support an optional 1-texel border.
	
	NPOTS textures are accessed by dimension-dependent (aka
	non-normalized) texture coordinates.  So instead of thinking of
	the texture image lying in a [0..1]x[0..1] range, the NPOTS texture
	image lies in a [0..w]x[0..h] range.
	
	This extension adds a new texture target and related state (proxy,
	binding, max texture size).

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/texture_rectangle.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.texture_rectangle import *
from OpenGL.raw.GL.ARB.texture_rectangle import _EXTENSION_NAME

def glInitTextureRectangleARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension OES.copy_image

This module customises the behaviour of the 
OpenGL.raw.GLES2.OES.copy_image to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension enables efficient image data transfer between image
	objects (i.e. textures and renderbuffers) without the need to bind
	the objects or otherwise configure the rendering pipeline.
	
	This is accomplised by adding a new entry-point CopyImageSubData,
	which takes a named source and destination.
	
	CopyImageSubData does not perform general-purpose conversions
	such as scaling, resizing, blending, color-space, or format
	conversions. It should be considered to operate in a manner
	similar to a CPU memcpy, but using the GPU for the copy.
	
	CopyImageSubData supports copies between images with different
	internal formats, if the formats are compatible as described in
	this extension.
	
	CopyImageSubData also supports copying between compressed and
	uncompressed images if the compressed block / uncompressed texel
	sizes are the same.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/copy_image.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.OES.copy_image import *
from OpenGL.raw.GLES2.OES.copy_image import _EXTENSION_NAME

def glInitCopyImageOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION